# -*- coding: utf-8 -*-

from warriors.warrior import Warrior

#apt-get install rpcbind
#You can check this module with irked.htb (10.10.10.117)
#Soft link to rpcdump.py

class Wrpc_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": self.proto+"_rpcdump", "cmd": 'python $(which rpcdump.py) -p 135 ' + self.host + " || echo 'rpcdump.py is not in path!'", "shell": True, "chain": False},
            {"name": self.proto+"_nmap_"+self.port, "cmd": "nmap -n -sV --script=msrpc-enum -p "+self.port+" "+self.host, "shell": True, "chain": False}
        ]

        msfmodules = [{"path": "scanner/dcerpc/endpoint_mapper", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                      {"path": "auxiliary/scanner/dcerpc/management", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                      {"path": "auxiliary/scanner/dcerpc/tcp_dcerpc_auditor", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                      {"path": "auxiliary/scanner/dcerpc/hidden", "toset": {"RHOSTS": self.host, "RPORT": self.port}}
                      ]

        self.cmds.append({"name": self.proto+"_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})




# -*- coding: utf-8 -*-

from warriors.warrior import Warrior


class Ftp_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": "ftp_nmap_"+self.port, "cmd": 'nmap -n -sV --script "ftp* and default" -p ' + self.port + ' ' + self.host, "shell": True, "chain": False},
            {"name": "ftp_version_"+self.port, "cmd": 'nc -w 20 -q 1 -vn ' + self.host + ' ' + self.port + ' </dev/null', "shell": True, "chain": False},

        ]

        msfmodules = [{"path": "auxiliary/scanner/ftp/anonymous", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                      {"path": "auxiliary/scanner/ftp/ftp_version", "toset": {"RHOSTS": self.host, "RPORT": self.port}},]

        self.cmds.append({"name": "ftp_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})

        if self.intensity >= "2":
            self.cmds.append({"name": "ftp_nmap_vuln_"+self.port, "cmd": 'nmap -sV --script "ftp* and vuln" -p ' + self.port + ' ' + self.host, "shell": True, "chain": False})
            msfmodules_vuln = [
                {"path": "auxiliary/scanner/ftp/bison_ftp_traversal", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                {"path": "auxiliary/scanner/ftp/colorado_ftp_traversal", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                {"path": "auxiliary/scanner/ftp/easy_file_sharing_ftp", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                {"path": "auxiliary/scanner/ftp/konica_ftp_traversal", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                {"path": "auxiliary/scanner/ftp/pcman_ftp_traversal", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                {"path": "auxiliary/scanner/ftp/titanftp_xcrc_traversal", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
            ]
            self.cmds.append({"name": "ftp_msf_vuln_"+self.port, "cmd": self.create_msf_cmd(msfmodules_vuln), "shell": True, "chain": False})

        if self.intensity == "3":
            self.extra_info = "You can use the variable 'username' to brute force a single username or the variable ulist to bruteforce a list of usernames."
            if username != "":
                self.cmds = [{"name": "ftp_brute_hydra_"+self.port, "cmd": 'hydra -f -e ns -l '+self.username+' -P '+self.plist+' -s '+self.port+' '+self.host+' ftp', "shell": True, "chain": False}]
            else:
                self.cmds = [{"name": "ftp_brute_hydra_"+self.port, "cmd": 'hydra -f -e ns -L ' + self.ulist + ' -P ' + self.plist + ' -s ' + self.port + ' ' + self.host + ' ftp',"shell": True, "chain": False}]



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior


class Saprouter_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        msfmodules = [
            {"path": "auxiliary/scanner/sap/sap_service_discovery", "toset": {"RHOSTS": self.host}},
            {"path": "auxiliary/scanner/sap/sap_router_info_request", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
            ]
        self.cmds.append({"name": self.proto+"_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior

#You can test this module against sizzle.htb (10.10.10.103)
#Soft link to samrdump.py

class Smb_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": "enum4linux", "cmd": 'enum4linux -a -u "'+self.username+'" -p "'+self.password+'" '+self.host, "shell": True, "chain": False},
            {"name": "smb_nmap", "cmd": 'nmap -n -sV --script "(safe and smb*) or smb-enum-*" -p 135,139,445 ' + self.host, "shell": True, "chain": False},
            {"name": "smbmap_"+self.port, "cmd": 'smbmap -u "'+self.username+'" -p "'+self.password+'" -H '+self.host+" -P "+self.port, "shell": True, "chain": False},
            {"name": "smbclient", "cmd": "smbclient -U '"+self.username+"%"+self.password+"' -L //" + self.host, "shell": False, "chain": False},
            {"name": "nbtscan", "cmd": 'nbtscan ' + self.host, "shell": False, "chain": False},
            {"name": "smb_samrdump_"+self.port, "cmd": 'python $(which samrdump.py) -port ' + self.port + ' ' + self.host, "shell": False, "chain": False},
        ]

        msfmodules = [
            {"path": "auxiliary/scanner/smb/smb_version", "toset": {"RHOSTS": self.host}},
        ]
        self.cmds.append({"name": self.proto + "_msf", "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})

        if username == "" or ("<" == username[0] and ">" == username[-1]):
            self.cmds.append({"name": "smbmap_guest_"+self.port, "cmd": 'smbmap -u "guest" -p "" -H '+self.host+" -P "+self.port, "shell": True, "chain": False})
            self.cmds.append({"name": "smbclient_guest", "cmd": "smbclient -U 'guest%' -L //" + self.host, "shell": True, "chain": False})
            self.cmds.append({"name": "enum4linux_guest", "cmd": 'enum4linux -a -u "guest" -p "" '+self.host, "shell": True, "chain": False})



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior

#https://github.com/SpiderLabs/ikeforce
#symlink
#You can test this against conceal.htb (10.10.10.116)

class Ike_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)
        self.password = self.password if len(self.password)>0 else "vpn"

        self.extra_info += "\nIf nothing is set in variable 'password' this module will use 'vpn' as ID."

        self.cmds = [
            {"name": "ike_nmap", "cmd": 'nmap -n -sV --script *ike* -sU -p ' + self.port + ' ' + self.host, "shell": False, "chain": False},
            {"name": "ike-scan", "cmd": 'ike-scan -M --sport '+self.port+' --dport '+self.port+' '+ self.host, "shell": False, "chain": True},
            {"name": "ike-scan_nat", "cmd": 'ike-scan -M --nat-t ' + self.host, "shell": False, "chain": True},
            {"name": "ike-scan_showback", "cmd": 'ike-scan -M --showbackoff --sport '+self.port+' --dport '+self.port+' ' + self.host,
             "shell": False, "chain": True},
            {"name": "ike-scan_agressive",
             "cmd": 'ike-scan --aggressive --id=' + self.password + ' --sport '+self.port+' --dport '+self.port+' '+self.host,
             "shell": False, "chain": True},
            {"name": "ike-scan_agr_psk",
             "cmd": 'ike-scan --pskcrack --aggressive --id='+self.password+' --sport '+self.port+' --dport '+self.port+' '+ self.host,
             "shell": False, "chain": True},
        ]

        if self.intensity == "3":
            self.extra_info = "To bruteforce IKE an 'ip' must be set."
            if self.ip != "":
                self.plist = self.plist if self.plist != "" else self.wordlists_path+'/wordlists/groupnames.txt'
                self.cmds.append({"name": "ikeforce_id", "cmd": 'ikeforce '+self.ip+' -e -w '+self.plist+' -s 2', "shell": False, "chain": True})
            # TODO: Bruteforce XAUTH and transformations (the 500 port is needed so the bruteforce has to be concatenated)



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior


class Smtp_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": self.proto+"_nmap_"+self.port, "cmd": 'nmap -n --script "smtp-open-relay or (default and *smtp*)" -p ' + self.port + ' ' + self.host, "shell": True, "chain": False},

        ]

        if self.proto == "smtp":
            self.cmds.append({"name": self.proto+"_version_"+self.port, "cmd": 'nc -w 20 -q 1 -vn ' + self.host + ' ' + self.port + ' </dev/null', "shell": True, "chain": False})
        else:
            self.cmds.append({"name": self.proto+"_version_"+self.port, "cmd": 'echo QUIT | openssl s_client -starttls smtp -crlf -connect '+self.host+':'+self.port, "shell": True, "chain": False})


        msfmodules = [{"path": "auxiliary/scanner/smtp/smtp_version", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                      {"path": "auxiliary/scanner/smtp/smtp_ntlm_domain", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                      {"path": "auxiliary/scanner/smtp/smtp_relay", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                      ]
        self.cmds.append({"name": self.proto+"_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})

        if self.intensity == 2:
            self.cmds.append({"name": self.proto+"_nmap_vuln_"+self.port, "cmd": 'nmap --script smtp-vuln-cve2011-1764,smtp-vuln-cve2011-1720,smtp-vuln-cve2010-4344  ' + self.host + ' ' + self.port, "shell": True, "chain": False})

        if self.intensity == "3":  # TODO: think about using other methods like RCT
            self.extra_info = "By default VRFY method is used, if you want to use other (EXPN or RCPT) set it in 'path' variable."
            self.extra_info += "\nYou can use the variable 'username' to brute force a single username or the variable ulist to bruteforce a list of usernames."
            self.path = "VRFY" if self.path.upper() not in ["EXPN", "RCPT"] else self.path.upper()
            if username != "":
                self.cmds = [{"name": self.proto+"_brute", "cmd": 'smtp-user-enum -M '+self.path+' -u ' + self.username + ' -p ' + self.port + ' -t ' + self.host, "shell": True, "chain": False}]
            else:
                self.cmds = [{"name": self.proto+"_brute", "cmd": 'smtp-user-enum -M '+self.path+' -U ' + self.ulist + ' -p ' + self.port + ' -t ' + self.host, "shell": True, "chain": False}]





#!/usr/bin/python3
# -*- coding: utf-8 -*-

import sys, os, re

from termcolor import colored

from lib.protocols import valid_protos
from warriors.afp_warrior import Afp_warrior
from warriors.ajp_warrior import Ajp_warrior
from warriors.bacnet_warrior import Bacnet_warrior
from warriors.cassandra_warrior import Cassandra_warrior
from warriors.checkpoint_warrior import Checkpoint_warrior
from warriors.couchdb_warrior import Couchdb_warrior
from warriors.dns_warrior import Dns_warrior
from warriors.enip_warrior import Enip_warrior
from warriors.finger_warrior import Finger_warrior
from warriors.ftp_warrior import Ftp_warrior
from warriors.scanner_warrior import Scanner_warrior
from warriors.http_warrior import Http_warrior
from warriors.ike_warrior import Ike_warrior
from warriors.imap_warrior import Imap_warrior
from warriors.irc_warrior import Irc_warrior
from warriors.iscsi_warrior import Iscsi_warrior
from warriors.ldap_warrior import Ldap_warrior
from warriors.memcache_warrior import Memcache_warrior
from warriors.modbus_warrior import Modbus_warrior
from warriors.mongodb_warrior import Mongodb_warrior
from warriors.mssql_warrior import Mssql_warrior
from warriors.mysql_warrior import Mysql_warrior
from warriors.ndmp_warrior import Ndmp_warrior
from warriors.nfs_warrior import Nfs_warrior
from warriors.ntp_warrior import Ntp_warrior
from warriors.oracle_warrior import Oracle_warrior
from warriors.pgsql_warrior import Pgsql_warrior
from warriors.pjl_warrior import Pjl_warrior
from warriors.pop_warrior import Pop_warrior
from warriors.portmapper_warrior import Portmapper_warrior
from warriors.rdp_warrior import Rdp_warrior
from warriors.redis_warrior import Redis_warrior
from warriors.rexec_warrior import Rexec_warrior
from warriors.rlogin_warrior import Rlogin_warrior
from warriors.jrmi_warrior import Jrmi_warrior
from warriors.rsh_warrior import Rsh_warrior
from warriors.rsync_warrior import Rsync_warrior
from warriors.rtsp_warrior import Rtsp_warrior
from warriors.saprouter_warrior import Saprouter_warrior
from warriors.smb_warrior import Smb_warrior
from warriors.smtp_warrior import Smtp_warrior
from warriors.snmp_warrior import Snmp_warrior
from warriors.ssh_warrior import Ssh_warrior
from warriors.telnet_warrior import Telnet_warrior
from warriors.vnc_warrior import Vnc_warrior
from warriors.wrpc_warrior import Wrpc_warrior
from warriors.x11_warrior import X11_warrior


def print_error(msg):
    print(colored("[-] Error: "+msg, 'red', attrs=['bold']))

def main_run(parser, proto, host, workdir, port, intensity, username, ulist, plist, protohelp, notuse, extensions, path, password,
             ipv6, domain, interactive, verbose, reexec, executed, exec):

    if not proto in valid_protos:
        if not interactive:
            parser.print_help(sys.stderr)
            sys.exit(1)
        else:
            print_error("Protocol '"+proto+"' is not valid")
            return -1

    if not os.path.isdir(workdir) or not os.access(workdir, os.W_OK):
        if not interactive:
            parser.print_help(sys.stderr)
            print_error("Not valid directory or not writable: " + workdir)
            sys.exit(2)
        else:
            print_error("Not valid directory or not writable: " + workdir)
            return -1

    if not protohelp and not host:
        if not interactive:
            parser.print_help(sys.stderr)
            print_error("A host is needed")
            sys.exit(3)
        else:
            print_error("Please, set a host")
            return -1

    # Heck domain name, ip and ip range if scanner
    if not re.match("^([a-z0-9]+(-[a-z0-9]+)*\.)+[a-z]{2,}$", host) and \
        not re.match(
            "^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])$",
            host) and \
        not (proto == "scanner" and re.match(
            "^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])/\d{1,2}$",
            host)):
                
        if not interactive:
            parser.print_help(sys.stderr)
            print_error("The provided host is not an IP nor a valid Domain")
            sys.exit(4)
        else:
            print_error("The provided host is not an IP nor a valid Domain")
            return -1

    #if protohelp and verbose:
    #    host = "<HOST>" if not host else host
    #    port = "<PORT>" if not port else port
    #    username = "<USERNAME_REQ>" if not username else username
    #    password = "<PASSWORD_REQ>" if not password else password
    #    ipv6 = "<IPv6_REQ>" if not ipv6 else ipv6
    #    domain = "<DOMAIN_REQ>" if not domain else domain
    #    path = "</SOME/PATH>" if not path else path

    if protohelp and verbose:
        host = "<HOST>"
        port = "<PORT>"
        username = "<USERNAME_REQ>"
        ulist = "<USERNAMES_LIST"
        password = "<PASSWORD_REQ>"
        plist = "<PASSWORDS_LIST>"
        ipv6 = "<IPv6_REQ>"
        domain = "<DOMAIN_REQ>"
        path = "</SOME/PATH>"
        extensions = "<extensions(php,asp,html)>"

    if proto == "ajp":
        warrior = Ajp_warrior(host, port, workdir, valid_protos["ajp"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "afp":
        warrior = Afp_warrior(host, port, workdir, valid_protos["afp"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "bacnet":
        warrior = Bacnet_warrior(host, port, workdir, valid_protos["bacnet"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "cassandra":
        warrior = Cassandra_warrior(host, port, workdir, valid_protos["cassandra"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "checkpoint":
        warrior = Checkpoint_warrior(host, port, workdir, valid_protos["checkpoint"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "couchdb":
        warrior = Couchdb_warrior(host, port, workdir, valid_protos["couchdb"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "dns":
        warrior = Dns_warrior(host, port, workdir, valid_protos["dns"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "enip":
        warrior = Enip_warrior(host, port, workdir, valid_protos["enip"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "finger":
        warrior = Finger_warrior(host, port, workdir, valid_protos["finger"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "ftp":
        warrior = Ftp_warrior(host, port, workdir, valid_protos["ftp"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "scanner":
        warrior = Scanner_warrior(host, port, workdir, valid_protos["scanner"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "http":
        warrior = Http_warrior(host, port, workdir, valid_protos["http"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)
    elif proto == "https":
        warrior = Http_warrior(host, port, workdir, valid_protos["https"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "ike":
        warrior = Ike_warrior(host, port, workdir, valid_protos["ike"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "imap":
        warrior = Imap_warrior(host, port, workdir, valid_protos["imap"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "imaps":
        warrior = Imap_warrior(host, port, workdir, valid_protos["imaps"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "irc":
        warrior = Irc_warrior(host, port, workdir, valid_protos["irc"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "iscsi":
        warrior = Iscsi_warrior(host, port, workdir, valid_protos["iscsi"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "jrmi":
        warrior = Jrmi_warrior(host, port, workdir, valid_protos["jrmi"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "ldap":
        warrior = Ldap_warrior(host, port, workdir, valid_protos["ldap"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "ldaps":
        warrior = Ldap_warrior(host, port, workdir, valid_protos["ldaps"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "memcache":
        warrior = Memcache_warrior(host, port, workdir, valid_protos["memcache"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "modbus":
        warrior = Modbus_warrior(host, port, workdir, valid_protos["modbus"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "mongodb":
        warrior = Mongodb_warrior(host, port, workdir, valid_protos["mongodb"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "mssql":
        warrior = Mssql_warrior(host, port, workdir, valid_protos["mssql"], intensity, username, ulist, password, plist, notuse, extensions,
                              path, reexec,
                              ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "mysql":
        warrior = Mysql_warrior(host, port, workdir, valid_protos["mysql"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "ndpm":
        warrior = Ndmp_warrior(host, port, workdir, valid_protos["ndpm"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "nfs":
        warrior = Nfs_warrior(host, port, workdir, valid_protos["nfs"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "ntp":
        warrior = Ntp_warrior(host, port, workdir, valid_protos["ntp"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "oracle":
        warrior = Oracle_warrior(host, port, workdir, valid_protos["oracle"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "pgsql":
        warrior = Pgsql_warrior(host, port, workdir, valid_protos["pgsql"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "pjl":
        warrior = Pjl_warrior(host, port, workdir, valid_protos["pjl"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "pop":
        warrior = Pop_warrior(host, port, workdir, valid_protos["pop"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "pops":
        warrior = Pop_warrior(host, port, workdir, valid_protos["pops"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "portmapper":
        warrior = Portmapper_warrior(host, port, workdir, valid_protos["portmapper"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "mssql":
        warrior = Mssql_warrior(host, port, workdir, valid_protos["mssql"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "rdp":
        warrior = Rdp_warrior(host, port, workdir, valid_protos["rdp"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "redis":
        warrior = Redis_warrior(host, port, workdir, valid_protos["redis"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "rexec":
        warrior = Rexec_warrior(host, port, workdir, valid_protos["rexec"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "rlogin":
        warrior = Rlogin_warrior(host, port, workdir, valid_protos["rlogin"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "rsh":
        warrior = Rsh_warrior(host, port, workdir, valid_protos["rsh"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "rsync":
        warrior = Rsync_warrior(host, port, workdir, valid_protos["rsync"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "rtsp":
        warrior = Rtsp_warrior(host, port, workdir, valid_protos["rtsp"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "saprouter":
        warrior = Saprouter_warrior(host, port, workdir, valid_protos["saprouter"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "smb":
        warrior = Smb_warrior(host, port, workdir, valid_protos["smb"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "smtp":
        warrior = Smtp_warrior(host, port, workdir, valid_protos["smtp"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "smtps":
        warrior = Smtp_warrior(host, port, workdir, valid_protos["smtps"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "snmp":
        warrior = Snmp_warrior(host, port, workdir, valid_protos["snmp"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "ssh":
        warrior = Ssh_warrior(host, port, workdir, valid_protos["ssh"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "telnet":
        warrior = Telnet_warrior(host, port, workdir, valid_protos["telnet"], intensity, username, ulist, password, plist, notuse, extensions,
                                path, reexec,
                                ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "vnc":
        warrior = Vnc_warrior(host, port, workdir, valid_protos["vnc"], intensity, username, ulist, password, plist, notuse, extensions,
                                 path, reexec,
                                 ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "wrpc":
        warrior = Wrpc_warrior(host, port, workdir, valid_protos["wrpc"], intensity, username, ulist, password, plist, notuse, extensions,
                                 path, reexec,
                                 ipv6, domain, interactive, verbose, executed, exec)

    elif proto == "x11":
        warrior = X11_warrior(host, port, workdir, valid_protos["x11"], intensity, username, ulist, password, plist, notuse, extensions,
                                 path, reexec,
                                 ipv6, domain, interactive, verbose, executed, exec)


    if protohelp:
        warrior.print_help()
    else:
        if not interactive:
            warrior.run()
        else:
            return warrior



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior


class Memcache_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": self.proto + "_nmap_"+self.port, "cmd": 'nmap -n -sV --script memcached-info -p ' + self.port + ' ' + self.host, "shell": True, "chain": False},
            {"name": self.proto + "_stats_"+self.port, "cmd": 'echo -e "stats\n" | nc -vn ' + self.host + ' ' + self.port, "shell": True, "chain": False},
        ]



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior


class Enip_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": self.proto+"_nmap_"+self.port, "cmd": 'nmap -n -sV --script enip-enumerate -p '+self.port+' '+self.host, "shell": True, "chain": False},
        ]



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior


class Imap_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)


        self.cmds = [
            {"name": self.proto + "_nmap_"+self.port, "cmd": 'nmap -n --scripts "imap* and default" -sV -p ' + self.port + ' ' + self.host, "shell": True, "chain": False},

        ]

        if self.proto == "imap":
            self.cmds.append({"name": self.proto + "_version_"+self.port, "cmd": 'nc -w 20 -q 1 -vn ' + self.host + ' ' + self.port + ' </dev/null', "shell": True, "chain": False})
        else:
            self.cmds.append({"name": self.proto + "_version_"+self.port, "cmd": 'echo "A1 Logout" | openssl s_client -connect '+self.host+':'+self.port+' -crlf -quiet', "shell": True, "chain": False})


        msfmodules = [{"path": "auxiliary/scanner/imap/imap_version", "toset": {"RHOSTS": self.host, "RPORT": self.port}}]

        self.cmds.append({"name": self.proto+"_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})

        if self.intensity == "3":
            self.extra_info = "You can use the variable 'username' to brute force a single username or the variable ulist to bruteforce a list of usernames."
            ssl = " -S " if self.proto == "imaps" else ""  # Check if SSL is needed
            if username != "":
                self.cmds = [{"name": self.proto+"_brute_hydra_"+self.port, "cmd": 'hydra -f -e ns -l '+self.username+' -P '+self.plist + ssl +' -s '+self.port+' '+self.host+' imap', "shell": True, "chain": False}]
            else:
                self.cmds = [{"name": self.proto+"_brute_hydra_"+self.port, "cmd": 'hydra -f -e ns -L ' + self.ulist + ' -P '+self.plist + ssl +' -s ' + self.port + ' ' + self.host + ' imap', "shell": True, "chain": False}]




# -*- coding: utf-8 -*-

from warriors.warrior import Warrior


class Couchdb_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": self.proto+"_version_"+self.port, "cmd": 'curl http://' + self.host_port+'/', "shell": True, "chain": False},
            {"name": self.proto+"_dbs_"+self.port, "cmd": 'curl http://' + self.host_port+'/_all_dbs', "shell": True, "chain": False},
        ]

        msfmodules = [
            {"path": "auxiliary/scanner/couchdb/couchdb_enum", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
        ]
        self.cmds.append(
            {"name": self.proto+"_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})

        if self.intensity >= "2":
            if self.username != "" and self.password != "":
                msfmodules_auth = [
                    {"path": "auxiliary/scanner/couchdb/couchdb_enum", "toset": {"RHOSTS": self.host, "RPORT": self.port, "HttpUsername": self.username, "HttpPassword": self.password}},
                    ]
                self.cmds.append({"name": self.proto+"_msf_auth_"+self.port, "cmd": self.create_msf_cmd(msfmodules_auth), "shell": True, "chain": False})

        if self.intensity == "3":
            self.extra_info = "You can use the variable 'username' to brute force a single username or the variable ulist to bruteforce a list of usernames."
            if username != "":
                msfmodules_brute = [{"path": "auxiliary/scanner/couchdb/couchdb_login", "toset": {"RHOSTS": self.host, "RPORT": self.port, "BLANK_PASSWORDS": "true", "USER_AS_PASS": "true", "USERNAME":self.username, "PASS_FILE": self.plist}},]
            else:
                msfmodules_brute = [{"path": "auxiliary/scanner/couchdb/couchdb_login", "toset": {"RHOSTS": self.host, "RPORT": self.port, "BLANK_PASSWORDS": "true", "USER_AS_PASS": "true", "USER_FILE": self.username, "PASS_FILE": self.plist}},]
            self.cmds = [{"name": self.proto+"_brute_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules_brute), "shell": True, "chain": False}]



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior


class Pgsql_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": self.proto+"_version_"+self.port, "cmd": 'nc -w 20 -q 1 -vn ' + self.host + ' ' + self.port + ' </dev/null', "shell": True,"chain": False},

        ]

        msfmodules = [
            {"path": "auxiliary/scanner/postgres/postgres_version", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
            {"path": "auxiliary/scanner/postgres/postgres_dbname_flag_injection", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
        ]
        self.cmds.append(
            {"name": self.proto+"_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})

        #Database name param needed
        #if self.intensity >= "2":
        #    if self.username != "" and self.username[-1] != ">" and self.password != "" and self.password[-1] != ">":
        #        msfmodules_auth = [
        #            {"path": "auxiliary/scanner/postgres/postgres_hashdump", "toset": {"RHOSTS": self.host, "RPORT": self.port, "DATABASE": self.databasetodo, "USERNAME": self.username, "PASSWORD": self.password}},
        #            {"path": "auxiliary/scanner/postgres/postgres_schemadump", "toset": {"RHOSTS": self.host, "RPORT": self.port, "DATABASE": self.databasetodo, "USERNAME": self.username, "PASSWORD": self.password}},
        #            {"path": "auxiliary/admin/postgres/postgres_readfile", "toset": {"RHOSTS": self.host, "RPORT": self.port, "DATABASE": self.databasetodo, "USERNAME": self.username, "PASSWORD": self.password}},
        #            ]
        #        self.cmds.append({"name": "pgsql_msf_auth_"+self.port, "cmd": self.create_msf_cmd(msfmodules_auth), "shell": True, "chain": False})

        if self.intensity == "3":
            self.extra_info = "You can use the variable 'username' to brute force a single username or the variable ulist to bruteforce a list of usernames."
            if username != "":
                self.cmds = [{"name": self.proto+"_brute_hydra_"+self.port, "cmd": 'hydra -f -e ns -l '+self.username+' -P '+self.plist+' -s '+self.port+' '+self.host+' postgres', "shell": True, "chain": False}]
            else:
                self.cmds = [{"name": self.proto+"_brute_hydra_"+self.port, "cmd": 'hydra -f -e ns -L ' + self.ulist + ' -P ' + self.plist + ' -s ' + self.port + ' ' + self.host + ' postgres', "shell": True, "chain": False}]



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior

# https://github.com/portcullislabs/udp-proto-scanner.git copy the conf file to bin also

#You can test this module against sizzle.htb (10.10.10.103)
#Or against conceal.htb(10.10.10.116)  (hidden snmp detected by udp-proto-scanner)

class Scanner_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)
        self.workdir = self.workdir + "/../"

        if self.ip != "":
            self.cmds = [{"name": "udp-proto-scanner", "cmd": 'udp-proto-scanner.pl ' + self.ip, "shell": False, "chain": False}]

        self.cmds += [
            {"name": "nmap_fast_udp", "cmd": 'nmap -F -sU -sV -T 4 -oA '+self.workdir+'nmapu '+ self.host, "shell": False, "chain": False},
            {"name": "nmap_init", "cmd": 'nmap -sS -sV -T 4 -oA '+self.workdir+'nmapi ' + self.host, "shell": False, "chain": True},
            {"name": "nmap_full_fast", "cmd": 'nmap -sS -sV -sC -O -T 4 -p - -oA '+self.workdir+'nmapff ' + self.host, "shell": False, "chain": True},
            {"name": "nmap_full", "cmd": 'nmap -sS -sV -sC -O -p - -oA '+self.workdir+'nmapf ' + self.host, "shell": False, "chain": True},
            {"name": "nmap_sctp_full", "cmd": 'nmap -T 4 -sY -sV -sC -p - -oA '+self.workdir+'nmapfsctp ' + self.host, "shell": False, "chain": False},
            #{"name": "nmap_udp_full", "cmd": 'nmap -sU -sV -p - ' + self.host, "shell": False, "chain": False}
        ]




# -*- coding: utf-8 -*-

from warriors.warrior import Warrior


class Finger_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": self.proto+"_cmd", "cmd": 'finger @' + self.host, "shell": True, "chain": False},
            {"name": self.proto+"_nmap_"+self.port, "cmd": 'nmap -n -sV --script finger -p ' + self.port + ' ' + self.host, "shell": True, "chain": False},
        ]

        msfmodules = [{"path": "auxiliary/scanner/finger/finger_users", "toset": {"RHOSTS": self.host, "RPORT": self.port}}]
        self.cmds.append({"name": self.proto+"_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})

        if self.intensity >= "2":
            self.cmds.append({"name": self.proto+"_execution", "cmd": 'finger "|/bin/id@' + self.host+'"', "shell": True, "chain": False})



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior

#Revisado
#apt-get install snmp-mibs-downloader
# in /etc/snmp/snmp.conf comment the line "mibs :"

#You can test this module against condeal.htb (10.10.10.116)

class Snmp_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)
        self.community = self.password if len(self.password)>0 else "public"
        self.plist = plist if plist != "" else self.wordlists_path+'/snmp_default_pass.txt'

        self.extra_info += "\nBy default the community string used is 'public'. If you want to use other, set it in the 'password' variable."

        self.cmds = [
            {"name": "snmpwalkv1", "cmd": 'snmpwalk -v 1 -c ' + self.community + ' ' + self.host, "shell": False, "chain": False},
            {"name": "snmpwalkv2c", "cmd": 'snmpwalk -v 2c -c ' + self.community + ' ' + self.host, "shell": False, "chain": False},
            {"name": "snmp_nmap_"+self.port, "cmd": 'nmap -n -sV --script "*snmp* and not brute and not dos" -p ' +self.port + " " + self.host, "shell": True, "chain": False},

        ]
        
        msfmodules = [{"path": "auxiliary/scanner/smb/smb2", "toset": {"RHOSTS": self.host, "RPORT": self.port}}]

        self.cmds.append({"name": "smb_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})

        if self.ip != "":
            self.cmds.append({"name": "snmp_check1_"+self.port, "cmd": 'snmp-check -p '+ self.port + ' -c ' + self.community + ' ' + self.ip, "shell": False, "chain": False})
            self.cmds.append({"name": "snmp_check2c_"+self.port, "cmd": 'snmp-check -v 2c -p ' + self.port + ' -c ' + self.community + ' ' + self.ip, "shell": False, "chain": False})

        if self.intensity == "3":
            self.cmds = [{"name": "snmp_brute_hydra_"+self.port, "cmd": 'hydra -f -P ' + self.plist + ' -s ' +self.port + ' ' + self.host + ' snmp', "shell": False, "chain": False}]




class Protocol():
    def __init__(self, name, ports, protos, nmap, only_ports, url, info):
        self.name = name
        self.defports = ports
        self.defproto = protos
        self.nmap = nmap
        self.only_ports = only_ports
        self.url = url
        self.info = info


general_protocol = Protocol("general", [""], [""], [""], False, "", "")

valid_protos = {
    "afp": Protocol("afp", ["548"], ["tcp"], ["afp"], False, "https://book.hacktricks.xyz/pentesting/584-pentesting-afp",
                  "The Apple Filing Protocol (AFP), formerly AppleTalk Filing Protocol, is a proprietary network protocol, and part of the Apple File Service (AFS), that offers file services for macOS and the classic Mac OS. In macOS, AFP is one of several file services supported. AFP currently supports Unicode file names, POSIX and access control listpermissions, resource forks, named extended attributes, and advanced file locking. In Mac OS 9 and previously, AFP was the primary protocol for file services."),
    "ajp": Protocol("ajp", ["8009"], ["tcp"], ["ajp"], False, "https://book.hacktricks.xyz/pentesting/8009-pentesting-apache-jserv-protocol-ajp",
                  "AJP is a wire protocol. It is an optimized version of the HTTP protocol to allow a standalone web server such as Apache to talk to Tomcat. Historically, Apache has been much faster than Tomcat at serving static content. The idea is to let Apache serve the static content when possible, but proxy the request to Tomcat for Tomcat related content."),
    "bacnet": Protocol("bacnet", ["47808"], ["udp"], ["BACNet"], False, "https://book.hacktricks.xyz/pentesting/47808-udp-bacnet",
                  "BACnet was designed to allow communication of building automation and control systems for applications such as heating, ventilating, and air-conditioning control (HVAC), lighting control, access control, and fire detection systems and their associated equipment. The BACnet protocol provides mechanisms for computerized building automation devices to exchange information, regardless of the particular building service they perform."),
    "cassandra": Protocol("cassandra", ["9160"], ["tcp"], ["cassandra"], False, "https://book.hacktricks.xyz/pentesting/cassandra",
                  "Apache Cassandra is a highly scalable, high-performance distributed database designed to handle large amounts of data across many commodity servers, providing high availability with no single point of failure. It is a type of NoSQL database. Let us first understand what a NoSQL database does."),
    "checkpoint": Protocol("checkpoint", ["264"], ["tcp"], [], False, "https://book.hacktricks.xyz/pentesting/pentesting-264-check-point-firewall-1",
                  "Check Point FireWall-1"),
    "couchdb": Protocol("couchdb", ["5984"], ["tcp"], [], False, "https://book.hacktricks.xyz/pentesting/5984-pentesting-couchdb",
                  "CouchDB is a document-oriented database and within each document fields are stored as key-value maps. Fields can be either a simple key/value pair, list, or map. Each document that is stored in the database is given a document-level unique identifier (_id) as well as a revision (_rev) number for each change that is made and saved to the database."),
    "dns": Protocol("dns", ["53"], ["udp"], ["domain"], True, "https://book.hacktricks.xyz/pentesting/pentesting-dns",
                  "The Domain Name Systems (DNS) is the phonebook of the Internet. Humans access information online through domain names, like nytimes.com or espn.com. Web browsers interact through Internet Protocol (IP) addresses. DNS translates domain names to IP addresses so browsers can load Internet resources."),
    "enip": Protocol("enip", ["44818"], ["tcp"], ["EtherNet/IP"], False, "https://book.hacktricks.xyz/pentesting/44818-ethernetip",
                  "EtherNet/IP is most commonly used in industrial automation control systems, such as those in water processing plants, manufacturing facilities and utilities. Several control system vendors have developed programmable automation controllers and I/O capable of communicating via EtherNet/IP."),
    "finger": Protocol("finger", ["79"], ["tcp"], ["finger"], False, "https://book.hacktricks.xyz/pentesting/pentesting-finger",
                  "Finger is a program that can be used to find information about computer users. It usually lists the login name, the full name, and possibly other details about the user you are fingering. These details may include the office location and phone number (if known), login time, idle time, time mail was last read, and the user's plan and project files."),
    "ftp": Protocol("ftp", ["21"], ["tcp"], ["ftp"], False, "https://book.hacktricks.xyz/pentesting/pentesting-ftp",
                  "The File Transfer Protocol (FTP) is a standard network protocol used for the transfer of computer files between a client and server on a computer network."),
    "https": Protocol("https", ["443", "10443", "1443", "80443"], ["tcp"], ["https", "ssl/http"], True, "https://book.hacktricks.xyz/pentesting/pentesting-web",
                  "HTTP means HyperText Transfer Protocol. HTTP is the underlying protocol used by the World Wide Web and this protocol defines how messages are formatted and transmitted, and what actions Web servers and browsers should take in response to various commands."),
    "http": Protocol("http", ["80", "1080", "8880", "8888", "9080", "9000", "10000", "10080"]+[str(i) for i in list(range(8000,8101))], ["tcp"], ["http"], True, "https://book.hacktricks.xyz/pentesting/pentesting-web",
                  "HTTP means HyperText Transfer Protocol. HTTP is the underlying protocol used by the World Wide Web and this protocol defines how messages are formatted and transmitted, and what actions Web servers and browsers should take in response to various commands."),
    "ike": Protocol("ike", ["500"], ["udp"], ["isakmp"], True, "https://book.hacktricks.xyz/pentesting/ipsec-ike-vpn-pentesting",
                  "IPsec is the most commonly used technology for both gateway-to-gateway (LAN-to-LAN) and host to gateway (remote access) enterprise VPN solutions. IKE is a type of ISAKMP (Internet Security Association Key Management Protocol) implementation, which is a framework for authentication and key exchange."),
    "imaps": Protocol("imaps", ["993"], ["tcp"], ["imaps"], False, "https://book.hacktricks.xyz/pentesting/pentesting-imap",
                  "As its name implies, IMAP allows you to access your email messages wherever you are; most of the time, it is accessed via the Internet. Basically, email messages are stored on servers. Whenever you check your inbox, your email client contacts the server to connect you with your messages. When you read an email message using IMAP, you aren't actually downloading or storing it on your computer; instead, you are reading it off of the server. As a result, it's possible to check your email from several different devices without missing a thing."),
    "imap": Protocol("imap", ["143"], ["tcp"], ["imap"], False, "https://book.hacktricks.xyz/pentesting/pentesting-imap",
                  "As its name implies, IMAP allows you to access your email messages wherever you are; most of the time, it is accessed via the Internet. Basically, email messages are stored on servers. Whenever you check your inbox, your email client contacts the server to connect you with your messages. When you read an email message using IMAP, you aren't actually downloading or storing it on your computer; instead, you are reading it off of the server. As a result, it's possible to check your email from several different devices without missing a thing."),
    "irc": Protocol("irc", ["6667", "6660–6669", "7000"], ["tcp"], ["irc"], False, "https://book.hacktricks.xyz/pentesting/pentesting-irc",
                  "IRC was originally a plain text protocol (although later extended), which on request was assigned port 194/TCP by IANA. However, the de facto standard have always been to run IRC on 6667/TCP and nearby port numbers (for example TCP ports 6660–6669, 7000) to avoid having to run the IRCd software with root privileges."),
    "iscsi": Protocol("iscsi", ["3260"], ["tcp"], ["iscsi"], False, "https://book.hacktricks.xyz/pentesting/3260-pentesting-iscsi",
                  "iSCSI is an acronym for Internet Small Computer Systems Interface, an Internet Protocol (IP)-based storage networking standard for linking data storage facilities. It provides block-level access to storage devices by carrying SCSI commands over a TCP/IP network. iSCSI is used to facilitate data transfers over intranets and to manage storage over long distances. It can be used to transmit data over local area networks (LANs), wide area networks (WANs), or the Internet and can enable location-independent data storage and retrieval."),
    "jrmi": Protocol("jrmi", ["1099"], ["tcp"], ["rmiregistry"], False, "https://book.hacktricks.xyz/pentesting/1099-pentesting-java-rmi",
                      "The Java Remote Method Invocation, or Java RMI, is a mechanism that allows an object that exists in one Java virtual machine to access and call methods that are contained in another Java virtual machine; This is basically the same thing as a remote procedure call, but in an object-oriented paradigm instead of a procedural one, which allows for communication between Java programs that are not in the same address space. One of the major advantages of RMI is the ability for remote objects to load new classes that aren't explicitly defined already, extending the behavior and functionality of an application."),
    "ldaps": Protocol("ldaps", ["636", "3269"], ["tcp"], [], False, "https://book.hacktricks.xyz/pentesting/pentesting-ldap",
                  "LDAP (Lightweight Directory Access Protocol) is a software protocol for enabling anyone to locate organizations, individuals, and other resources such as files and devices in a network, whether on the public Internet or on a corporate intranet. LDAP is a 'lightweight' (smaller amount of code) version of Directory Access Protocol (DAP). Typical LDAP ports are  389 and 636(ldaps) but Global Catalog is available by default on ports 3268, and 3269 for LDAPS."),
    "ldap": Protocol("ldap", ["389", "3268"], ["tcp"], ["ldap"], False, "https://book.hacktricks.xyz/pentesting/pentesting-ldap",
                  "LDAP (Lightweight Directory Access Protocol) is a software protocol for enabling anyone to locate organizations, individuals, and other resources such as files and devices in a network, whether on the public Internet or on a corporate intranet. LDAP is a 'lightweight' (smaller amount of code) version of Directory Access Protocol (DAP). Typical LDAP ports are  389 and 636(ldaps) but Global Catalog is available by default on ports 3268, and 3269 for LDAPS."),
    "memcache": Protocol("memcache", ["11211"], ["tcp"], [], False, "https://book.hacktricks.xyz/pentesting/11211-memcache",
                  "Memcache is a general-purpose distributed memory caching system. It is often used to speed up dynamic database-driven websites by caching data and objects in RAM to reduce the number of times an external data source (such as a database or API) must be read."),
    "modbus": Protocol("modbus", ["502"], ["tcp"], ["modbus"], False, "https://book.hacktricks.xyz/pentesting/pentesting-modbus",
                  "Modbus Protocol is a messaging structure developed by Modicon in 1979. It is used to establish master-slave/client-server communication between intelligent devices."),
    "mongodb": Protocol("mongodb", ["27017", "27018"], ["tcp"], ["mongodb "], False, "https://book.hacktricks.xyz/pentesting/27017-27018-mongodb",
                  "MongoDB is an open source database management system (DBMS) that uses a document-oriented database model which supports various forms of data."),
    "mssql": Protocol("mssql", ["1443"], ["tcp"], ["ms-sql"], False, "https://book.hacktricks.xyz/pentesting/pentesting-mssql-microsoft-sql-server",
                  "Microsoft SQL Server is a relational database management system developed by Microsoft. As a database server, it is a software product with the primary function of storing and retrieving data as requested by other software applications—which may run either on the same computer or on another computer across a network (including the Internet)."),
    "mysql": Protocol("mysql", ["3306"], ["tcp"], ["mysql"], False, "https://book.hacktricks.xyz/pentesting/pentesting-mysql",
                  "MySQL is a freely available open source Relational Database Management System (RDBMS) that uses Structured Query Language (SQL)."),
    "ndmp": Protocol("ndmp", ["10000"], ["tcp"], ["ndmp"], False, "https://book.hacktricks.xyz/pentesting/10000-network-data-management-protocol-ndmp",
                  "NDMP, or Network Data Management Protocol, is a protocol meant to transport data between network attached storage (NAS) devices and backup devices. This removes the need for transporting the data through the backup server itself, thus enhancing speed and removing load from the backup server."),
    "nfs": Protocol("nfs", ["2049"], ["tcp"], ["nfs"], False, "https://book.hacktricks.xyz/pentesting/nfs-service-pentesting",
                  "It is a client/server system that allows users to access files across a network and treat them as if they resided in a local file directory."),
    "ntp": Protocol("ntp", ["123"], ["udp"], ["ntp"], False, "https://book.hacktricks.xyz/pentesting/pentesting-ntp",
                  "The Network Time Protocol (NTP) is a networking protocol for clock synchronization between computer systems over packet-switched, variable-latency data networks."),
    "oracle": Protocol("oracle", ["1521","1522-1529"], ["tcp"], ["oracle-tns"], False, "https://book.hacktricks.xyz/pentesting/1521-1522-1529-pentesting-oracle-listener",
                  "Oracle database (Oracle DB) is a relational database management system (RDBMS) from the Oracle Corporation. You need to install some dependencies to pentest this service: https://book.hacktricks.xyz/pentesting/1521-1522-1529-pentesting-oracle-listener/oracle-pentesting-requirements-installation"),
    "pgsql": Protocol("pgsql", ["5432", "5433"], ["tcp"], ["pgsql"], False, "https://book.hacktricks.xyz/pentesting/pentesting-postgresql",
                  "PostgreQSL is an open source object-relational database system that uses and extends the SQL language."),
    "pjl": Protocol("pjl", ["9100"], ["tcp"], ["jetdirect"], False, "https://book.hacktricks.xyz/pentesting/9100-pjl",
                  "The Printer Job Language (PJL) was originally introduced by HP but soon became a de facto standard for print job control. ‘PJL resides above other printer languages’ and can be used to change settings like paper tray or size. It must however be pointed out that PJL is not limited to the current print job as some settings can be made permanent. PJL can also be used to change the printer's display or read/write files on the device. There are many dialects as vendors tend to support only a subset of the commands listed in the PJL reference and instead prefer to add proprietary ones."),
    "pops": Protocol("pops", ["995"], ["tcp"], ["pop3"], False, "https://book.hacktricks.xyz/pentesting/pentesting-pop",
                  "Post Office Protocol (POP) is a type of computer networking and Internet standard protocol that extracts and retrieves email from a remote mail server for access by the host machine. POP is an application layer protocol in the OSI model that provides end users the ability to fetch and receive email."),
    "pop": Protocol("pop", ["110"], ["tcp"], ["pop3"], False, "https://book.hacktricks.xyz/pentesting/pentesting-pop",
                  "Post Office Protocol (POP) is a type of computer networking and Internet standard protocol that extracts and retrieves email from a remote mail server for access by the host machine. POP is an application layer protocol in the OSI model that provides end users the ability to fetch and receive email."),
    "portmapper": Protocol("portmapper", ["111"], ["tcp"], ["rpcbind"], False, "https://book.hacktricks.xyz/pentesting/pentesting-rpcbind",
                  "Provides information between Unix based systems. Port is often probed, it can be used to fingerprint the Nix OS, and to obtain information about available services. Port used with NFS, NIS, or any rpc-based service."),
    "rdp": Protocol("rdp", ["3389"], ["tcp"], ["ms-wbt-server"], False, "https://book.hacktricks.xyz/pentesting/pentesting-rdp",
                  "Remote Desktop Protocol (RDP) is a proprietary protocol developed by Microsoft, which provides a user with a graphical interface to connect to another computer over a network connection. The user employs RDP client software for this purpose, while the other computer must run RDP server software"),
    "redis": Protocol("redis", ["6379"], ["tcp"], [], False, "https://book.hacktricks.xyz/pentesting/6379-pentesting-redis",
                  "Redis is an open source (BSD licensed), in-memory data structure store, used as a database, cache and message broke."),
    "rexec": Protocol("rexec", ["512"], ["tcp"], ["exec"], False, "https://book.hacktricks.xyz/pentesting/512-pentesting-rexec",
                  "It is a service that allows you to execute a command inside a host if you know valid credentials (username and password)."),
    "rlogin": Protocol("rlogin", ["513"], ["tcp"], ["login"], False, "https://book.hacktricks.xyz/pentesting/pentesting-rlogin",
                  "This service was mostly used in the old days for remote administration but now because of security issues this service has been replaced by the slogin and the ssh."),
    "rsh": Protocol("rsh", ["514"], ["tcp"], [], False, "https://book.hacktricks.xyz/pentesting/pentesting-rsh",
                  "Rsh use .rhosts files and /etc/hosts.equiv for authentication. These methods relied on IP addresses and DNS (Domain Name System) for authentication."),
    "rsync": Protocol("rsync", ["873"], ["tcp"], ["rsync"], False, "https://book.hacktricks.xyz/pentesting/873-pentesting-rsync",
                  "rsync is a utility for efficiently transferring and synchronizing files between a computer and an external hard drive and across networked computers by comparing the modification timesand sizes of files.[3] It is commonly found on Unix-like operating systems. The rsync algorithm is a type of delta encoding, and is used for minimizing network usage. Zlib may be used for additional data compression,[3] and SSH or stunnel can be used for security."),
    "rtsp": Protocol("rtsp", ["554", "8554"], ["tcp"], ["rtsp"], False, "https://book.hacktricks.xyz/pentesting/554-8554-pentesting-rtsp",
                  "The Real Time Streaming Protocol (RTSP) is a network control protocol designed for use in entertainment and communications systems to control streaming media servers. The protocol is used for establishing and controlling media sessions between end points. Clients of media servers issue VHS-style commands, such as play, record and pause, to facilitate real-time control of the media streaming from the server to a client (Video On Demand) or from a client to the server (Voice Recording)."),
    "saprouter": Protocol("saprouter", ["3299"], ["tcp"], ["saprouter"], False, "https://book.hacktricks.xyz/pentesting/3299-pentesting-saprouter",
                  "Saprouter is basically a reverse proxy for SAP systems, typically sitting between the Internet and internal SAP systems. Its main purpose is to allow controlled access from hosts on the Internet to the internal SAP systems, since it allows for a finer grained control of SAP protocols than a typical firewall."),
    "scanner": Protocol("scanner", [""], ["tcp", "udp"], [], False, "",
                  "This module will scan the IP using nmap (one fast and on top ports, another fast in all the ports and another slower on all the ports) and udp-proto-scanner.pl"),
    "smb": Protocol("smb", ["445", "139"], ["tcp"], ["microsoft-ds", "netbios-ssn"], True, "https://book.hacktricks.xyz/pentesting/pentesting-smb",
                  "Server Message Block in modern language is also known as Common Internet File System. The system operates as an application-layer network protocol primarily used for offering shared access to files, printers, serial ports, and other sorts of communications between nodes on a network. For instance, on Windows, SMB can run directly over TCP/IP without the need for NetBIOS over TCP/IP. This will use, as you point out, port 445. On other systems, you’ll find services and applications using port 139. This means that SMB is running with NetBIOS over TCP/IP."),
    "smtps": Protocol("smtp", ["587", "465"], ["tcp"], [], False, "https://book.hacktricks.xyz/pentesting/pentesting-smtp",
                  "SMTP (Simple Mail Transfer Protocol) is a TCP/IP protocol used in sending and receiving e-mail. However, since it is limited in its ability to queue messages at the receiving end, it is usually used with one of two other protocols, POP3 or IMAP."),
    "smtp": Protocol("smtp", ["25"], ["tcp"], ["smtp"], False, "https://book.hacktricks.xyz/pentesting/pentesting-smtp",
                  "SMTP (Simple Mail Transfer Protocol) is a TCP/IP protocol used in sending and receiving e-mail. However, since it is limited in its ability to queue messages at the receiving end, it is usually used with one of two other protocols, POP3 or IMAP."),
    "snmp": Protocol("snmp", ["161", "162", "10161", "10162"], ["udp"], ["snmp"], False, "https://book.hacktricks.xyz/pentesting/pentesting-snmp",
                  "SNMP - Simple Network Management Protocol is a protocol used to monitor different devices in the network (like routers, switches, printers, IoTs...)."),
    "ssh": Protocol("ssh", ["22"], ["tcp"], ["ssh"], False, "https://book.hacktricks.xyz/pentesting/pentesting-ssh",
                  "SSH or Secure Shell or Secure Socket Shell, is a network protocol that gives users a secure way to access a computer over an unsecured network."),
    "telnet": Protocol("telnet", ["23"], ["tcp"], ["telnet"], False, "https://book.hacktricks.xyz/pentesting/pentesting-telnet",
                  "Telnet is a network protocol that gives users a UNsecure way to access a computer over a network."),
    "vnc": Protocol("vnc", ["5900", "5901", "5800", "5801"], ["tcp"], ["vnc"], False, "https://book.hacktricks.xyz/pentesting/pentesting-vnc",
                  "In computing, Virtual Network Computing (VNC) is a graphical desktop-sharing system that uses the Remote Frame Buffer protocol (RFB) to remotely control another computer. It transmits the keyboard and mouse events from one computer to another, relaying the graphical-screen updates back in the other direction, over a network. "),
    "wrpc": Protocol("wrpc", ["135"], ["tcp"], ["msrpc"], True, "https://book.hacktricks.xyz/pentesting/135-penstesting-wrpc",
                  "Microsoft Remote Procedure Call, also known as a function call or a subroutine call, is a protocol that uses the client-server model in order to allow one program to request service from a program on another computer without having to understand the details of that computer's network. MSRPC was originally derived from open source software but has been developed further and copyrighted by Microsoft."),
    "x11": Protocol("x11", ["6000"], ["tcp"], ["X11"], False, "https://book.hacktricks.xyz/pentesting/6000-pentesting-x11",
                  "The X Window System (aka X) is a windowing system for bitmap displays, which is common on UNIX-based operating systems. X provides the basic framework for a GUI based environment. X also does not mandate the user interface – individual programs handle this."),
}



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior

#You can test this module against querier (10.10.10.125)

class Mssql_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": self.proto+"_nmap_"+self.port, "cmd": 'nmap -n --script ms-sql-info,ms-sql-empty-password,ms-sql-xp-cmdshell,ms-sql-config,ms-sql-ntlm-info,ms-sql-tables,ms-sql-hasdbaccess,ms-sql-dac,ms-sql-dump-hashes --script-args mssql.username=sa,mssql.password=,mssql.instance-name=MSSQLSERVER -sV -p ' + self.port + ' ' + self.host, "shell": True, "chain": False},

        ]

        msfmodules = [{"path": "auxiliary/scanner/mssql/mssql_ping", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                      ]
        self.cmds.append({"name": self.proto+"_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})

        if self.intensity >= "2":
            self.extra_info = "If you set the username and password, more authenticated metasploit modules will be executed."
            if username != "" and password != "":
                msfmodules_auth = [
                    {"path": "auxiliary/admin/mssql/mssql_enum", "toset": {"RHOSTS": self.host, "RPORT": self.port, "USERNAME": self.username, "PASSWORD": self.password}},
                    {"path": "admin/mssql/mssql_enum_domain_accounts", "toset": {"RHOSTS": self.host, "RPORT": self.port, "USERNAME": self.username, "PASSWORD": self.password}},
                    {"path": "admin/mssql/mssql_enum_sql_logins", "toset": {"RHOSTS": self.host, "RPORT": self.port, "USERNAME": self.username, "PASSWORD": self.password}},
                    {"path": "auxiliary/admin/mssql/mssql_escalate_dbowner", "toset": {"RHOSTS": self.host, "RPORT": self.port, "USERNAME": self.username, "PASSWORD": self.password}},
                    {"path": "auxiliary/admin/mssql/mssql_escalate_execute_as", "toset": {"RHOSTS": self.host, "RPORT": self.port, "USERNAME": self.username, "PASSWORD": self.password}},
                    {"path": "auxiliary/admin/mssql/mssql_exec", "toset": {"RHOSTS": self.host, "RPORT": self.port, "CMD": "ipconfig", "USERNAME": self.username, "PASSWORD": self.password}},
                    {"path": "auxiliary/admin/mssql/mssql_findandsampledata", "toset": {"RHOSTS": self.host, "RPORT": self.port, "USERNAME": self.username, "PASSWORD": self.password}},
                    {"path": "auxiliary/scanner/mssql/mssql_hashdump", "toset": {"RHOSTS": self.host, "RPORT": self.port, "USERNAME": self.username, "PASSWORD": self.password}},
                    {"path": "auxiliary/scanner/mssql/mssql_schemadump", "toset": {"RHOSTS": self.host, "RPORT": self.port, "USERNAME": self.username, "PASSWORD": self.password}},
                    ]
                self.cmds.append({"name": self.proto+"_msf_auth_"+self.port, "cmd": self.create_msf_cmd(msfmodules_auth), "shell": True, "chain": False})

        if self.intensity == "3":
            self.extra_info = "You can use the variable 'username' to brute force a single username or the variable ulist to bruteforce a list of usernames."
            if username != "":
                self.cmds = [{"name": self.proto+"_brute_hydra_"+self.port, "cmd": 'hydra -f -e ns -l '+self.username+' -P '+self.plist+' -s '+self.port+' '+self.host+' mssql', "shell": True, "chain": False}]
            else:
                self.cmds = [{"name": self.proto+"_brute_hydra_"+self.port, "cmd": 'hydra -f -e ns -L ' + self.ulist + ' -P ' + self.plist + ' -s ' + self.port + ' ' + self.host + ' mssql', "shell": True, "chain": False}]



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior


class Cassandra_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": self.proto + "_nmap_"+self.port, "cmd": 'nmap -n -sV --script cassandra-info -p ' + self.port + ' ' + self.host, "shell": True, "chain": False},

        ]

        if self.intensity == "3":
            self.extra_info = "You can use the variable 'username' to brute force a single username or the variable ulist to bruteforce a list of usernames."
            if username != "":
                self.cmds = [{"name": self.proto+"_brute_nmap_"+self.port, "cmd": 'nmap -n -sV --script cassandra-brute --script-args userdb='+self.username+',passdb='+self.plist+' -p '+self.port+' '+self.host, "shell": True, "chain": False}]
            else:
                self.cmds = [{"name": self.proto+"_brute_nmap_"+self.port, "cmd": 'nmap -n -sV --script cassandra-brute --script-args userdb='+self.ulist+',passdb='+self.plist+' -p '+self.port+' '+self.host, "shell": True, "chain": False}]



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior

#You can test this module against sizzle.htb (10.10.10.103) and ypuffy (10.10.10.107)

class Ldap_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": "ldap_nmap_"+self.port, "cmd": 'nmap -n -sV --script "ldap* and not brute" -p ' + self.port + ' ' + self.host, "shell": True, "chain": False},
        ]

        if self.intensity >= "2":
            if domain != "" and path != "":
                self.cmds.append({"name": "ldapsearch", "cmd": "ldapsearch -x -h " +self.host+ " -D '" +self.domain+ "\\" +self.username+ "' -w '" +self.password+ "' -b 'DC=" +self.domain+ ",DC=" +self.path+ "'", "shell": True, "chain": False})
            if username != "" and password != "" and domain != "":
                self.cmds.append({"name": "ldapdomaindump", "cmd": "ldapdomaindump --no-json --no-grep --authtype SIMPLE -o "+self.workdir+" -r " +self.host+ " -u '" + self.domain + "\\" + self.username + "' -p '" + self.password+"' && echo 'To see the HTML output go to: "+self.workdir+"'", "shell": True, "chain": False})

        #The script ldap-brute lock accounts very fast, is better to not use it
        #if self.intensity:
        #    self.cmds = [
        #        {"name": "nmap_ldap", "cmd": 'nmap -sV --script "ldap*" -p ' + self.port + ' ' + self.host, "shell": False,
        #         "chain": False},
        #    ]



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior


class Telnet_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": "telnet_nmap_"+self.port, "cmd": 'nmap -n -sV --script "telnet* and safe" -p ' + self.port + ' ' + self.host, "shell": True, "chain": False},
            {"name": "telnet_version_"+self.port, "cmd": 'nc -w 20 -q 1 -vn ' + self.host + ' ' + self.port + ' </dev/null', "shell": True, "chain": False},
        ]

        msfmodules = [{"path": "auxiliary/scanner/telnet/telnet_version", "toset": {"RHOSTS": self.host, "RPORT": self.port}}, ]
        self.cmds.append({"name": "telnet_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})

        if self.intensity >= "2":
            msfmodules_vulns = [
                                {"path": "auxiliary/scanner/telnet/brocade_enable_login", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                                {"path": "auxiliary/scanner/telnet/telnet_encrypt_overflow", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                                {"path": "auxiliary/scanner/telnet/telnet_ruggedcom", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                                ]
            self.cmds.append(
                {"name": "telnet_msf_vuln_"+self.port, "cmd": self.create_msf_cmd(msfmodules_vulns), "shell": True, "chain": False})

        if self.intensity == "3":
            if username != "":
                self.cmds = [{"name": "telnet_brute_hydra_"+self.port, "cmd": 'hydra -f -e ns -l ' + self.username + ' -P ' + self.plist + ' -s ' + self.port + ' ' + self.host + ' telnet', "shell": True, "chain": False}]
            else:
                self.cmds = [{"name": "telnet_brute_hydra_"+self.port, "cmd": 'hydra -f -e ns -L ' + self.ulist + ' -P ' + self.plist + ' -s ' + self.port + ' ' + self.host + ' telnet', "shell": True, "chain": False}]




#!/usr/bin/python3
# -*- coding: utf-8 -*-

import argparse, sys, os

from lib.main import main_run
from lib.interact import LegionPrompt
from os.path import expanduser

# Execute: python3 legion.py <protocol> --host <IP> [--port <PORT>] [--workdir <PATH>] [-v] [-b] [-u <username] [-U usernamesList] [-P passwordsList] [--protohelp] [--notuse <Ex: nmap,gobuster,dirsearch>]  


def check_args(args=None):
    parser = argparse.ArgumentParser(description='Automatically analyze +45 protocols.')
    parser.add_argument('--proto', default='scanner',
                        help='Protocol to test (Default: "scanner")')
    parser.add_argument('--host', default="127.0.0.1",
                        help='Host to test (Default: 127.0.0.1)')
    parser.add_argument('--workdir', default=expanduser("~")+'/.legion/',
                        help='Working directory (Default: '+expanduser("~")+'/.legion/)')
    parser.add_argument('-p', '--port',  type=int, default=0,
                        help='Port where the protocol is listening (default one will be used if not set). Always default is used by: DNS, RCPinfo')
    parser.add_argument('-i', '--intensity', type=int,
                        default=2, help='1-Main checks, 2-Main and more vulns checks (default), 3-Only Service Bruteforce')
    parser.add_argument('-u', '--username',
                        default="", help='Username to use in bruteforce')
    parser.add_argument('-U', '--ulist', default="",
                        help='Usernames to use in bruteforce (Windows and Unix users list setted by default)')
    parser.add_argument('-k', '--password',
                        default="", help='Password to use(smb, community snmp, groupid IKE)')
    parser.add_argument('-P', '--plist', default="",
                        help='Passwords to use in bruteforce (passwords to brute, dnssubdomain brute, snmp communities brute setted by default to the protocols who need them)')
    parser.add_argument('--protohelp',  action="store_true",
                        default=False, help='Set to get help of selected protocol')
    parser.add_argument('--notuse', default="",
                        help='Comma separate string of name of tools that you dont want to be used')
    parser.add_argument('--extensions', default="html,txt,php,asp,aspx",
                        help='USED IN HTTP/s: Set valid extensions of the web server (Default: html,txt,php,asp,aspx)')
    parser.add_argument('--path', default="",
                        help='USED IN HTTP/s: Set the URL path like /path/to/file.php')
    parser.add_argument('--ipv6', default="",
                        help='USED IN HTTP/s: Used for reverse dns lookup with ipv6')
    parser.add_argument('--domain', default="",
                        help='If possible, set the domain name here and the VictimIP in --host')
    parser.add_argument('--execonly', default="",
                        help='Exec only this tool')
    parser.add_argument('-r', '--run', action="store_true", default=False,
                        help='Just run the analysis')
    parser.add_argument('-v', '--verbose', action="store_true", default=True,
                        help='Get output when the command finish (default: True)')

    args = parser.parse_args()
    return (parser, args.proto.lower(), args.host, args.workdir, str(args.port), str(args.intensity), args.username,
            args.ulist, args.plist, args.protohelp, args.notuse.split(","), args.extensions, args.path, args.password,
            args.ipv6, args.domain, args.execonly, args.run, args.verbose)


def main():
    parser, proto, host, workdir, port, intensity, username, ulist, plist, protohelp, notuse, extensions, path, password, ipv6, \
        domain, execonly, run, verbose = check_args(sys.argv[1:])

    interactive = not run

    if os.getuid() != 0:
        exit("Please, execute this script as root.")

    try:
        if not os.path.isdir(workdir):
            os.mkdir(workdir)
    except Exception as e:
        print("The workdir directory: '"+workdir+"' could not be created!\nExiting...")

    if not interactive:
        main_run(parser, proto, host, workdir, port, intensity, username, ulist, plist, protohelp, notuse, extensions, path,
                 password, ipv6, domain, interactive, verbose, False, [], execonly)

    else:
        LegionPrompt(parser, proto, host, workdir, port, intensity, username, ulist, plist, notuse, extensions, path, password,
                     ipv6, domain, verbose).cmdloop()


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior

#You can test this module against querier (10.10.10.125)

class Modbus_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": self.proto+"_nmap_"+self.port, "cmd": 'nmap-n  --script modbus-discover -sV -p ' + self.port + ' ' + self.host, "shell": True, "chain": False},

        ]

        msfmodules = [{"path": "auxiliary/scanner/scada/modbusdetect", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                      {"path": "auxiliary/scanner/scada/modbus_findunitid", "toset": {"RHOSTS": self.host, "RPORT": self.port}}
                      ]
        self.cmds.append({"name": self.modbus+"_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior


class Mongodb_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": "mongodb_nmap_"+self.port, "cmd": 'nmap -n -sV --script "mongo* and default" -p '+self.port+' '+self.host, "shell": True, "chain": False},
        ]


        if self.intensity == "3":
            self.extra_info = "You can use the variable 'username' to brute force a single username or the variable ulist to bruteforce a list of usernames."
            if username != "":
                msfmodules_brute = [{"path": "auxiliary/scanner/mongodb/mongodb_login", "toset": {"RHOSTS": self.host, "RPORT": self.port, "BLANK_PASSWORDS": "true", "USER_AS_PASS": "true", "USERNAME":self.username, "PASS_FILE": self.plist}}]
            else:
                msfmodules_brute = [{"path": "auxiliary/scanner/mongodb/mongodb_login", "toset": {"RHOSTS": self.host, "RPORT": self.port, "BLANK_PASSWORDS": "true", "USER_AS_PASS": "true", "USER_FILE": self.username, "PASS_FILE": self.plist}},]
            self.cmds = [{"name": "mongodb_brute_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules_brute), "shell": True, "chain": False}]



# -*- coding: utf-8 -*-

import os

from time import sleep
from termcolor import colored
from threading import Thread

from warriors.warrior import Warrior
from lib.main import main_run
from lib.main import valid_protos
from lib.protocols import general_protocol

#The workdir of general is /home/username/.legion/host//

class General(Warrior):
    def __init__(self, parser, host, port, workdir, proto, intensity, username, ulist, password, plist, notuse, engine, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        self.parser = parser
        Warrior.__init__(self, host, port,  workdir, general_protocol, intensity, username, ulist, password, plist, notuse, engine, path, reexec, ipv6, domain, interactive, verbose, executed, exec)
        self.engine, self.ipv6 = "", ""
        self.protohelp = False
        self.checked = []
        self.stop = False
        self.ws = []
        self.myexecuted = []

    def run_proto(self, line, proto, port):
        if proto+port in self.myexecuted:
            return
        else:
            self.myexecuted.append(proto+port)
        for w in self.ws:
            self.executed.append(w.get_executed())
        if line:
            print()
            print(colored("Found " + str(port) + " opened for " + proto + ", sending warriors...: ", "blue", attrs=['bold'])+colored(line, "yellow", attrs=['bold']))

        warrior = main_run(self.parser, proto, self.host, self.workdir+"/../../", port, self.intensity, self.username, self.ulist, self.plist, self.protohelp,
                 self.notuse, self.engine, self.path, self.password, self.ipv6, self.domain, self.interactive, self.verbose, self.reexec, self.executed, self.exec)
        self.ws.append(warrior)
        thread = Thread(target=warrior.run)
        thread.start()
        sleep(3)

    def get_warriors(self):
        return self.ws

    def run(self):
        self.run_proto("", "scanner", "1337")

        while not self.stop:
            for root, dirs, files in os.walk(self.workdir+"/../scanner/"):
                for file in files:
                    with open(os.path.join(root, file), 'r') as f:
                        cont = f.readlines()

                    self.check_cont(cont, file)
            sleep(2)

    def check_cont(self, cont, file):
        if "nmap" in file:
            for line in cont:
                if line[0] in '1234567890':  # If 1st number, then port
                    port = line.split("/")[0]
                    if "tcp" in line and "open" in line:
                        for p in valid_protos:
                            if "tcp" in valid_protos[p].defproto:
                                if port in valid_protos[p].defports or (not (valid_protos[p].only_ports) and any([n in line for n in valid_protos[p].nmap])):
                                    self.run_proto(line, valid_protos[p].name, port)
                                    break

                    elif "udp" in line and "open" in line and not "filtered" in line:
                        for p in valid_protos:
                            if "udp" in valid_protos[p].defproto:
                                if port in valid_protos[p].defports or (not (valid_protos[p].only_ports) and any([n in line for n in valid_protos[p].nmap])):
                                    self.run_proto(line, valid_protos[p].name, port)
                                    break

        if "udp-proto-scanner" in file:
            for line in cont:
                if line.split(" ")[0] == "Received":
                    if "DNSVersionBindReq" in line:
                        self.run_proto(line, "dns", "53")
                    elif "snmp-public" in line:
                        self.run_proto(line, "snmp", "161")
                    elif "ike" in line:
                        self.run_proto(line, "ike", "500")


    def stop_general(self):
        self.stop = True



#!/usr/bin/python3
# -*- coding: utf-8 -*-

import os, sys, signal

from threading import Thread
from termcolor import colored
from cmd import Cmd
from time import sleep

from lib.main import main_run
from lib.main import valid_protos
from lib.main import print_error
from warriors.general import General


class LegionPrompt(Cmd):
    intro = """\
    
██╗     ███████╗ ██████╗ ██╗ ██████╗ ███╗   ██╗
██║     ██╔════╝██╔════╝ ██║██╔═══██╗████╗  ██║
██║     █████╗  ██║  ███╗██║██║   ██║██╔██╗ ██║
██║     ██╔══╝  ██║   ██║██║██║   ██║██║╚██╗██║
███████╗███████╗╚██████╔╝██║╚██████╔╝██║ ╚████║
╚══════╝╚══════╝ ╚═════╝ ╚═╝ ╚═════╝ ╚═╝  ╚═══╝ v2.0"""+colored("\nI wanted to destroy everything beautiful I'd never have\n", 'red', attrs=['bold'])
    prompt = '('+colored("legion", 'blue', attrs=['bold'])+') > '

    def __init__(self, parser, proto, host, workdir, port, intensity, username, ulist, plist, notuse, extensions, path, password,
                 ipv6, domain, verbose):
        Cmd.__init__(self)
        self.all_values = {"proto": proto, "host": host, "workdir": workdir, "port": port, "intensity": intensity,
                           "username": username, "ulist": ulist, "plist": plist, "notuse": notuse, "extensions": extensions,
                           "path": path, "password": password, "ipv6": ipv6, "domain": domain, "verbose": verbose,
                           "reexec": False}

        self.priv_values = {"interactive": True, "protohelp": False, "executed": [], "exec": ""}
        self.parser = parser
        self.ws = []
        self.general = ""
        self.msgs = {}

    def emptyline(self):
        pass

    def do_exit(self, inp):
        '''exit the application'''
        print("Bye!")
        self.stop_procs()
        os.kill(os.getpid(), signal.SIGTERM)

    def do_quit(self, inp):
        '''exit the application'''
        print("Bye!")
        self.stop_procs()
        os.kill(os.getpid(), signal.SIGTERM)

    def do_stopall(self, inp):
        '''Stop ALL running processes'''
        self.stop_procs()

    def do_stop(self, procname):
        '''Stop a process given the name'''
        self.stop_p(procname)

    def do_protos(self, args):
        '''List the name of valid protocols'''
        c = 0
        for i, p in enumerate(valid_protos):
            clr = "green" if p not in ["scanner"] else "blue"
            myend = "\t\t" if len(p) < 8 else "\t"
            if c % 3 != 0:
                print(colored(p, clr, attrs=['bold']), end=myend)
            else:
                print("\n"+colored(p, clr, attrs=['bold']), end=myend)
            c += 1
        print()
        print(colored("There are a total of "+str(len(valid_protos))+" supported protocols", "yellow", attrs=['bold']))

    def do_set(self, args):
        '''Set variable value: set proto http'''
        if len(args.split(" ")) < 2:
            print_error("set <variable> <value>")
        else:
            variable = args.split(" ")[0].lower()
            value = args.split(" ")[1].strip()
            if variable == "proto" and value.lower() not in valid_protos:
                print_error("Not valid protocol: "+value)
            elif variable in ["port", "intensity"] and not value.isdigit():
                print_error("Please set a number: "+value)
            elif variable in ["reexec", "verbose"] and not value.lower() in ["true", "false"]:
                print_error("Please set a boolean(true or false): "+value)
            elif variable.lower() in self.all_values:
                value = value if not value.lower() in ["true", "false"] else (True if value.lower() == "true" else False)
                self.all_values[variable] = value
                print(colored(variable.capitalize(), "blue", attrs=['bold']) + ": " + colored(str(value), "yellow", attrs=['bold']))
            else:
                print_error(variable + " is not valid")

    def do_unset(self, args):
        '''Set variable to null'''
        if len(args.split(" ")) < 1:
            print_error("unset <variable>")
        else:
            variable = args.split(" ")[0].lower()
            if variable.lower() in self.all_values:
                self.all_values[variable] = ""
                print(colored(variable.capitalize(), "blue", attrs=['bold']) + ": " + colored("Null", "magenta", attrs=['bold']))
            else:
                print_error(variable + " is not valid")

    def do_get(self, args):
        '''Get variable value: get proto'''
        variable = args.split(" ")[0].lower()
        if variable.lower() in self.all_values:
            print(variable + ": " + str(self.all_values[variable]))
        else:
            print_error(variable + " is not valid")

    def do_options(self, _):
        '''Get all Parameters and their value'''
        for key, value in sorted(self.all_values.items()):
            if key == "proto":
                print(colored(str(key) + ": ", 'yellow', attrs=['bold']) + str(value))
            else:
                print(colored(str(key)+": ", 'cyan', attrs=['bold'])+str(value))

    def do_procs(self, _):
        '''Get information about running and run processes'''
        self.print_procs(self.ws)
        if self.general != "":
            print()
            print(colored("Warriors sent by the General:", "blue", attrs=['bold', 'underline']))
            self.print_procs(self.general.get_warriors())
        print("")

    def do_out(self, filename):
        '''Get the output of a executed tool: getout smbclient'''
        name = filename + ".out"
        for root, dirs, files in os.walk(self.all_values["workdir"]+"/"+self.all_values["host"]):
            if name in files:
                with open(os.path.join(root, name), 'r') as f:
                    print(f.read())
                    break

    def do_err(self, filename):
        '''Get the error of a executed tool: geterr smbclient'''
        name = filename + ".err"
        for root, dirs, files in os.walk(self.all_values["workdir"]):
            if name in files:
                with open(os.path.join(root, name), 'r') as f:
                    print(f.read())
                    break
    
    def do_info(self, _):
        '''Get info of the selected protocol'''
        self.priv_values["protohelp"] = True
        self.initW()
        self.priv_values["protohelp"] = False

    def do_run(self, _):
        '''Execute the confiured protocol attack'''
        self.priv_values["protohelp"] = False
        self.update_executed()
        warrior = self.initW()

        if warrior != -1:  # If -1, then something went wrong creating the warrior
            self.ws.append(warrior)
            thread = Thread(target=warrior.run)
            thread.start()
        else:
            print_error("Something went wrong, nothing is going to be executed")

    def do_exec(self, args):
        '''Execute the indicated cmd'''
        if len(args.split(" ")) != 1:
            print_error("exec <CMDname>")
        else:
            cmd = args.split(" ")[0].lower()
            self.priv_values["exec"] = cmd
            warrior = self.initW()
            self.priv_values["exec"] = ""

            if warrior != -1:  # If -1, then something went wrong creating the warrior
                self.ws.append(warrior)
                thread = Thread(target=warrior.run)
                thread.start()
            else:
                print_error("Something went wrong, nothing is going to be executed")


    def do_startGeneral(self, _):
        '''Star a General that will help. Automatize the scan and launch of scripts depending on the discovered services. Only one at the same time is allowed.'''
        if self.general == "":
            print(colored("Starting General", "blue", attrs=['bold']))
            self.general = General(self.parser, self.all_values["host"], "0", self.all_values["workdir"], "/", self.all_values["intensity"],
                        self.all_values["username"], self.all_values["ulist"], self.all_values["password"], self.all_values["plist"],
                        self.all_values["notuse"], self.all_values["extensions"], self.all_values["path"], self.all_values["reexec"],
                        self.all_values["ipv6"], self.all_values["domain"], self.priv_values["interactive"],
                        self.all_values["verbose"], self.priv_values["executed"], self.priv_values["exec"])

            thread = Thread(target=self.general.run)
            thread.start()
        else:
            print(colored("general is already running... You can stop it with stopGeneral",'blue'))

    def do_stopGeneral(self, _):
        '''Stop the general'''
        print(colored("Stopping General...", 'blue', attrs=['bold']))
        self.general.stop_general()
        self.general = ""

    def initW(self):
        '''Initialize the current Warrior'''
        return main_run(self.parser, self.all_values["proto"], self.all_values["host"],
                 self.all_values["workdir"], self.all_values["port"], self.all_values["intensity"],
                 self.all_values["username"], self.all_values["ulist"],
                 self.all_values["plist"], self.priv_values["protohelp"], self.all_values["notuse"],
                 self.all_values["extensions"], self.all_values["path"], self.all_values["password"],
                 self.all_values["ipv6"], self.all_values["domain"], self.priv_values["interactive"],
                 self.all_values["verbose"], self.all_values["reexec"], self.priv_values["executed"],
                 self.priv_values["exec"])

    def print_procs(self, ws):
        last = ""
        ws = sorted(ws, key=lambda x: x.get_proto())
        for w in ws:
            if type(w) is int:
                print_error("An INT was found as a WARRIOR, TAKE A LOOK!")
                continue
            if last != w.get_proto():
                print()
                print(colored(w.get_proto(), 'blue', attrs=['reverse', 'bold']))
            last = w.get_proto()
            procs, ch = w.get_procs_info()
            procs = sorted(procs, key=lambda x: x["name"])
            for p in procs:
                if p["proc"].is_alive():
                    print(colored(p["name"] + ": ", 'yellow', attrs=['blink', 'bold']) + p["cmd"])
                else:
                    print(colored(p["name"] + ": ", 'green', attrs=['bold']) + p["cmd"])
            if ch:
                print(colored("Command require sequencial object, waiting for execute next commnad...", 'red', attrs=['bold']))

    def get_pids(self):
        for w in self.ws:
            self.msgs = {**self.msgs, **w.get_all_queue()}
        if self.general != "":
            for w in self.general.get_warriors():
                self.msgs = {**self.msgs, **w.get_all_queue()}

    def stop_p(self, param_name):
        self.get_pids()
        self.kill_pbyname(param_name)


    def stop_procs(self):
        self.proc_stop_procs(self.ws)
        if self.general != "":
            self.proc_stop_procs(self.general.get_warriors())

    def proc_stop_procs(self, ws):
        rep = True
        while rep:
            rep = False
            self.get_pids()
            for w in ws:
                procs, ch = w.get_procs_info()
                for p in procs:
                    if p["proc"].is_alive():
                        self.kill_pbyname(p["name"])
                        rep = True
                        sleep(0.5)

    def kill_pbyname(self, pname):
        if pname in self.msgs:
            os.kill(int(self.msgs[pname]), signal.SIGKILL)
            print(colored("Terminated: ", 'green', attrs=['bold']) + pname + "("+str(self.msgs[pname])+")")
        else:
            print(colored("Not found: ", 'red', attrs=['bold']) + pname)

    def update_executed(self):
        for w in self.ws:
            self.priv_values["executed"].append(w.get_executed())
        if self.general != "":
            for w in self.general.get_warriors():
                self.priv_values["executed"].append(w.get_executed())



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior


class Jrmi_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": self.proto+"_nmap_"+self.port, "cmd": 'nmap -n -sV --script "rmi-dumpregistry or rmi-vuln-classloader" ' + self.port + ' ' + self.host, "shell": True, "chain": False},
        ]

        msfmodules = [{"path": "auxiliary/scanner/misc/java_rmi_server", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
                      {"path": "auxiliary/gather/java_rmi_registry", "toset": {"RHOSTS": self.host, "RPORT": self.port}},]
        self.cmds.append({"name": self.proto+"_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior

class Redis_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": self.proto+"_nmap_"+self.port, "cmd": 'nmap -n --script redis-info -sV -p ' + self.port + ' ' + self.host, "shell": True, "chain": False},
        ]

        msfmodules = [
            {"path": "auxiliary/scanner/redis/redis_server", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
        ]
        self.cmds.append(
            {"name": self.proto+"_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})

        if self.intensity == "3":
            self.cmds = [{"name": self.proto+"_brute_hydra_"+self.port, "cmd": 'hydra -f -P '+self.plist+' -s '+self.port+' '+self.host+' redis', "shell": True, "chain": False}]



# -*- coding: utf-8 -*-

import sys, os, socket, re

from termcolor import colored
from subprocess import Popen
from multiprocessing import Process, Queue
from time import sleep


def print_error(msg):
    print(colored("[-] Error: "+msg, 'red', attrs=['bold']))

class Warrior:
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        self.host = host
        self.port = port if port == "<PORT>" or int(port) > 0 < 65536 else protocol.defports[0]
        self.proto = protocol.name
        self.workdir = workdir + "/" + self.host + "/" + self.proto + "/" +self.port
        self.intensity = intensity
        self.username = username
        self.ulist = ulist
        self.password = password
        self.plist = plist
        self.notuse = notuse if type(notuse) is list else notuse.split(",")
        self.interactive = interactive
        self.verbose = verbose
        self.extensions = extensions
        self.path = path
        self.reexec = reexec
        self.ipv6 = ipv6
        self.domain = domain
        self.exec = exec

        self.q = Queue()                                        # Queue used to send the PID of the processes
        self.cmds = []                                          # CMDs that are going to be executed
        self.demand_cmds = []                                   # List of other possible CMDs to execute
        self.processes = []                                     # List of running/run processed
        self.executed = executed                                # List of name of processes executed
        self.proto_info = protocol.info                         # Basic protocol information
        self.proto_url = protocol.url                           # URL with more info about the protocol
        self.extra_info = ""                                    # This should be overwritten inside the warrior, if needed
        self.defport_info = {"ports": protocol.defports, "tcp": "tcp" in protocol.defproto, "udp": "udp" in protocol.defproto}  # Info about the default ports used
        self.proto_host = self.proto+"://"+self.host            # http://127.0.0.1
        self.host_port = self.host+":"+self.port                # Ex: 127.0.0.1:8080
        self.proto_host_port = self.proto_host+":"+self.port    # Ex: http://127.0.0.1:8080
        self.proto_host_port_path = self.proto_host + ":" + self.port + self.path  # Ex: http://127.0.0.1:8080/some/path.php
        self.victim_file = self.workdir+"/"+"victim"            # File where the host is written
        self.isChained = False                                  # Process needs to wait to finish before executing next
        self.ip = self.host if re.match("^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])$", self.host) else ""  # If host is an IP fill this field
        self.wordlists_path = os.path.dirname(os.path.realpath(__file__)) + '/../wordlists/'
        self.git_path = os.path.dirname(os.path.realpath(__file__)) + '/../git/'

        self.ulist = ulist if len(ulist) > 0 else self.wordlists_path + '/users.txt'
        self.plist = plist if len(plist) > 0 else self.wordlists_path + '/passwords.txt'

        # If host is a domain
        if re.match("^([a-z0-9]+(-[a-z0-9]+)*\.)+[a-z]{2,}$", self.host):
            self.ip = socket.gethostbyname(self.host)                       # If host is a domain, get the IP
            self.domain = self.host if self.domain == "" else self.domain   # If host is a domain, fill this field

        self.write_host()

    def execute(self, q, cmd, name, shell=False):
        cmdl = cmd
        if not shell:
            cmd = cmd.split(" ")
        with open(self.workdir+"/"+name+".out", "wb") as out, open(self.workdir+"/"+name+".err", "wb") as err:
            try:
                pw = Popen(cmd, stdout=out, stderr=err, shell=shell)
                print(colored("Executing ",'yellow', attrs=['bold']) + colored(name, 'cyan', attrs=['bold']) + colored(" with PID: ", 'yellow', attrs=['bold']) + colored(str(pw.pid), 'cyan', attrs=['bold']) + colored(" Command: ", 'yellow', attrs=['bold'])+ cmdl)
                q.put(name+","+str(pw.pid))
                pw.communicate()
            except Exception as e:
                print_error("Something has happened with "+name+" (Exception: "+str(e)+")")
        if self.interactive:
            print(colored(name, 'green', attrs=['bold']))
            if self.verbose:
                self.getout(name)

    def get_all_queue(self):
        '''Obtiene la relacion  "nombre",pid  de los mensajes de la cola'''
        msgs = []
        fm = {}
        while not self.q.empty():
            msgs.append(self.q.get())

        for msg in msgs:
            msgsplit = msg.split(",")
            if len(msgsplit) > 1:
                fm[msgsplit[0]] = msgsplit[1]
        return fm

    def get_executed(self):
        return self.executed

    def exec_proc(self, cmd):
        CY = '\033[33m'
        NC = '\033[0m'
        p = { "name": cmd["name"], "cmd": cmd["cmd"] }
        p["proc"] = Process(target=self.execute, args=(self.q, cmd["cmd"], cmd["name"], cmd["shell"]))
        self.processes.append(p)
        self.processes[-1]["proc"].start()
        if cmd["chain"]:  # If chain, wait it to finish
            self.isChained = True
            if not self.interactive:
                sys.stdout.write('\r'+CY+"[I] Waiting..."+NC)
            self.processes[-1]["proc"].join()
            if not self.interactive:
                sys.stdout.flush()
            self.isChained = False

    def get_procs_info(self):
        return (self.processes, self.isChained)

    def get_proto(self):
        return self.proto

    def print_help(self):
        l4_proto = "tcp,udp" if self.defport_info["tcp"] and self.defport_info["udp"] else ("tcp" if self.defport_info["tcp"] else ("udp" if self.defport_info["udp"] else ""))
        print(colored("Protocol Resume", "blue", attrs=['bold', 'underline']))
        print(colored(self.proto_info, "green", attrs=['bold']))
        if self.defport_info["ports"]:
            print(colored("Default(s) port: ", "blue", attrs=['bold']) + ", ".join(self.defport_info["ports"]) + "("+colored(l4_proto, "blue")+")" )
        if self.proto_url:
            print(colored("URL with more information: ", "blue", attrs=['bold']) + colored(self.proto_url,'cyan', attrs=['bold']))
        if self.extra_info:
            print(colored(self.extra_info, "magenta", attrs=['bold']))
        print()
        print("For "+colored(self.proto.upper(), 'cyan', attrs=['bold'])+" will be executed:")
        for cmd in self.cmds:
            if all([(tool not in cmd["cmd"]) if len(tool) > 1 else True for tool in self.notuse]):  # Check for notuse
                print(colored(cmd["name"]+":", 'blue', attrs=['bold']), colored(cmd["cmd"], 'yellow', attrs=['bold']))
        print()
        if self.demand_cmds:
            if all([(tool not in cmd["cmd"]) if len(tool) > 1 else True for tool in self.notuse]):  # Check for notuse
                print("For " + colored(self.proto.upper(), 'cyan', attrs=['bold']) + " on demand cmds could be executed:")
                for cmd in self.demand_cmds:
                    print(colored(cmd["name"] + ":", 'blue', attrs=['bold']), colored(cmd["cmd"], 'yellow', attrs=['bold']))

    def write_host(self):
        if not os.path.exists(self.workdir):
            os.makedirs(self.workdir)
        with open(self.victim_file,'w') as f:
            f.write(self.host)

    def run(self):
        CG = '\033[92m'
        NC = '\033[0m'
        if self.exec != "":
            for cmd in self.demand_cmds + self.cmds:
                if self.exec in cmd["name"]:
                    self.executed.append(cmd)
                    self.exec_proc(cmd)
                    sleep(0.15)
        else:
            for cmd in self.cmds:
                if all([(tool not in cmd["cmd"]) if len(tool)>1 else True for tool in self.notuse]) and (cmd not in self.executed or self.reexec):  # Check for notuse
                    self.executed.append(cmd)
                    self.exec_proc(cmd)
                    sleep(0.15)
        if not self.interactive:
            while any(p["proc"].is_alive() for p in self.processes):
                sleep(1)
                sys.stdout.flush()
                to_write = "\rProcessing "+", ".join([p["name"] if p["proc"].is_alive() else CG+p["name"]+NC for p in self.processes])+"\t\t\tCompleted: {0:03}%".format(int(len([p for p in self.processes if not p["proc"].is_alive()])*100/len(self.processes)))
                sys.stdout.write(to_write)
            sys.stdout.flush()

    def getout(self, filename):
        '''Get the output of a executed tool: getout smbclient'''
        name = filename + ".out"
        for root, dirs, files in os.walk(self.workdir):
            if name in files:
                with open(os.path.join(root, name), 'r') as f:
                    print(f.read())
                    break

    def create_msf_cmd(self, params):
        cmd = "msfconsole -q -x '"
        for param in params:
            cmd += "use " + param["path"] + ";"
            for key in param["toset"]:
                cmd += "set "+key+" "+param["toset"][key]+";"
            cmd += "run;"
        cmd += "exit'"
        return cmd



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior

class Oracle_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)
        self.sids = plist if len(plist) > 0 else self.wordlists_path+'/sids-oracle.txt'

        self.cmds = [
            {"name": self.proto+"_nmap_"+self.port, "cmd": 'nmap -n --script "oracle-tns-version" -T4 -sV -p '+ self.port + ' ' + self.host, "shell": True, "chain": False},
            {"name": self.proto+"_tnscmd10g_version_"+self.port, "cmd": 'tnscmd10g version -p '+ self.port +' -h '+ self.host, "shell": False, "chain": False},
            {"name": self.proto+"_tnscmd10g_status_"+self.port, "cmd": 'tnscmd10g status -p '+ self.port +' -h '+ self.host, "shell": False, "chain": False},
            {"name": self.proto+"_oscanner_"+self.port, "cmd": 'oscanner -p '+ self.port +' -s '+ self.host, "shell": False, "chain": False},
            {"name": self.proto+"_odat_all_"+self.port, "cmd": 'odat.py all -p '+ self.port +' -s '+ self.host, "shell": False, "chain": False},
            {"name": self.proto+"_hydra_sids_"+self.port, "cmd": 'hydra -f -L '+self.sids+' -s '+self.port+' '+self.host+' oracle-sid', "shell": False, "chain": False},
            
        ]

        if self.intensity >= "2":
            self.extra_info = "Set the SID that you want to brute force in the 'username' option"
            if username != "":
                self.cmds.append({"name": self.proto+"_brute_nmap_"+self.port, "cmd": 'nmap -sV --script oracle-brute-stealth --script-args oracle-brute-stealth.sid='+self.username+' -p '+ self.port + ' ' + self.host, "shell": True, "chain": False},)

        #TODO: Add user/password bruteforce (not enough variables: SID, username, password)
        #All the checks that can perform metasploit are already made




# -*- coding: utf-8 -*-

from warriors.warrior import Warrior

class Ssh_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": "ssh_nmap_"+self.port, "cmd": 'nmap -n -sV --script "ssh-auth-methods or ssh-auth-methods or ssh2-enum-algos or sshv1" -p ' + self.port + ' ' + self.host, "shell": True, "chain": False},
            {"name": "ssh_sslscan_"+self.port, "cmd": "sslscan "+self.host_port, "shell": False, "chain": False},
            {"name": "ssh_sslyze_"+self.port, "cmd": "sslyze --regular "+self.host_port, "shell": False, "chain": False},
            {"name": "ssh_version_"+self.port, "cmd": 'nc -w 20 -q 1 -vn ' + self.host + ' ' + self.port+ ' </dev/null', "shell": True, "chain": False},
        ]

        msfmodules = [{"path": "auxiliary/scanner/ssh/ssh_version", "toset": {"RHOSTS": self.host, "RPORT": self.port}}]
        self.cmds.append({"name": "ssh_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})

        if self.intensity >= "2":
            msfmodules_vulns = [{"path": "scanner/ssh/ssh_enumusers", "toset": {"RHOSTS": self.host, "RPORT": self.port, "USER_FILE": self.ulist}},
                                {"path": "auxiliary/scanner/ssh/juniper_backdoor", "toset": {"RHOSTS": self.host, "RPORT": self.port}}]
            self.cmds.append({"name": "ssh_msf_vuln_"+self.port, "cmd": self.create_msf_cmd(msfmodules_vulns), "shell": True, "chain": False})

        if self.intensity == "3":
            self.extra_info = "You can use the variable 'username' to brute force a single username or the variable ulist to bruteforce a list of usernames."
            if username != "":
                self.cmds = [{"name": "ssh_brute_hydra_"+self.port, "cmd": 'hydra -f -e ns -l ' + self.username + ' -P ' + self.plist + ' -s ' + self.port + ' ' + self.host + ' ssh', "shell": True, "chain": False}]
            else:
                self.cmds = [{"name": "ssh_brute_hydra_"+self.port, "cmd": 'hydra -f -e ns -L ' + self.ulist + ' -P ' + self.plist + ' -s ' + self.port + ' ' + self.host + ' ssh', "shell": True, "chain": False}]




# -*- coding: utf-8 -*-

from warriors.warrior import Warrior

#apt-get install rpcbind
#You can check this module with irked.htb (10.10.10.117)

class Ntp_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": "ntp_nmap", "cmd": 'nmap -n -sV --script "ntp* and (discovery or vuln) and not (dos or brute)" -p ' + self.port + " " + self.host, "shell": False, "chain": False},
            {"name": "ntpq_readvar", "cmd": 'ntpq -c readvar ' + self.host, "shell": False, "chain": False},
            {"name": "ntpq_monlist", "cmd": 'ntpq -c monlist ' + self.host, "shell": False, "chain": False},
            {"name": "ntpq_peers", "cmd": 'ntpq -c peers ' + self.host, "shell": False, "chain": False},
            {"name": "ntpq_listpeers", "cmd": 'ntpq -c listpeers ' + self.host, "shell": False, "chain": False},
            {"name": "ntpq_ntpversion", "cmd": 'ntpq -c ntpversion ' + self.host, "shell": False, "chain": False},
            {"name": "ntpq_sysinfo", "cmd": 'ntpq -c sysinfo ' + self.host, "shell": False, "chain": False},
        ]



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior

class Http_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds=[
            {"name": self.proto+"_nikto_"+self.port, "cmd": 'echo n | nikto -nointeractive -maxtime 45m -timeout 60 -host '+self.proto_host_port_path+' -Plugins "paths;outdated;report_sqlg;auth;content_search;report_text;fileops;parked;shellshock;report_html;cgi;headers;report_nbe;favicon;cookies;robots;report_xml;report_csv;ms10_070;msgs;drupal;apache_expect_xss;siebel;put_del_test;apacheusers;dictionary;embedded;ssl;clientaccesspolicy;httpoptions;subdomain;negotiate;sitefiles;mutiple_index;strutshock;dishwasher;paths;docker_registry;origin_reflection;dir_traversal;multiple_index"', "shell": True, "chain": False},
            {"name": self.proto+"_whatweb_"+self.port, "cmd": "whatweb -a 3 "+self.proto_host_port_path, "shell": False, "chain": False},
            {"name": self.proto + "_robots_"+self.port, "cmd": 'curl ' + self.proto_host_port + '/robots.txt -L -k --user-agent "Googlebot/2.1 (+http://www.google.com/bot.html)" --connect-timeout 30 --max-time 180', "shell": True, "chain": False},
            {"name": self.proto+"_nmap_"+self.port, "cmd": 'nmap -n -sV --script "(http* and not (dos or brute) and not http-xssed)" -p '+self.port+' '+self.host, "shell": True, "chain": False},
            {"name": self.proto+"_wafw00f_"+self.port, "cmd": 'wafw00f '+self.proto_host_port_path, "shell": False, "chain": False},
            {"name": self.proto+"_fast_dirsearch_"+self.port, "cmd": "dirsearch -F -r -u " + self.proto_host_port_path + " -e " + self.extensions, "shell": False,"chain": False},
            {"name": self.proto+"_dirhunt_"+self.port, "cmd": "dirhunt "+self.proto_host_port_path, "shell": False, "chain": False},
            #{"name": "gobuster", "cmd": "gobuster -k -fw -w /usr/share/wordlists/dirbuster/directory-list-2.3-medium.txt -u "+self.proto_host_port_path+" -x html,txt,"+self.extensions, "shell": False, "chain": False},
            #{"name":"dirb","cmd": "dirb -S " + self.proto_host_port_path + " -X ." + self.extensions.replace(",",",."), "shell": False, "chain": False}, #Dirb needs the extension with a point. The flag '-f' in dirsearch makes it behave like dirb (force ext and "/")
            {"name": self.proto+"_cmsmap_"+self.port, "cmd": 'echo "y" | cmsmap -s '+self.proto_host_port_path, "shell": True, "chain": False},
            {"name": self.proto + "_curl_put_"+self.port, "cmd": 'curl -v -X PUT -d "Hey! I am a PUT" ' + self.proto_host_port_path + "/legion.txt", "shell": True, "chain": False},
            {"name": self.proto + "_gobuster_vhosts_"+self.port, "cmd": 'gobuster vhost -u "' + self.proto_host_port + '" -t 50 -w "' + self.wordlists_path+'/subdomains-top1million-110000.txt"', "shell": True, "chain": False},

        ]

        #if self.domain and self.ip:
        #    self.cmds.append({"name": self.proto+"_vhost-brute", "cmd": "vhost-brute.php --domain "+self.domain+" --ip "+self.ip+" --wordlist "+self.wordlists_path+'/subdomains.txt' + (" --ssl" if self.proto == "https" else ""), "shell": False, "chain": False})

        if self.proto == "https":
            self.cmds.append({"name": "https_sslscan_"+self.port, "cmd": "sslscan "+self.host_port, "shell": False, "chain": False})
            self.cmds.append({"name": "https_sslyze_"+self.port, "cmd": "sslyze --regular "+self.host_port, "shell": False, "chain": False})
            self.cmds.append({"name": "https_ssl_nmap_"+self.port, "cmd": 'nmap -sV --script "ssl-* and not brute and not dos" -p ' + self.port + " " +self.host, "shell": True, "chain": False})

        if self.intensity >= "2":
            self.cmds.append({"name": self.proto + "_medium_dirsearch_"+self.port, "cmd": "dirsearch -f -F -r -u " + self.proto_host_port_path + " -e " + self.extensions + " -w /usr/share/dirb/wordlists/common.txt", "shell": False, "chain": False})
            self.cmds.append({"name": self.proto + "_medium_dirsearch_raft_"+self.port, "cmd": "dirsearch -f -F -r -u " + self.proto_host_port_path + " -e " + self.extensions + ' -w ' + self.wordlists_path+'/raft-medium-words.txt', "shell": False, "chain": False})

        if self.intensity == "3":
            self.extra_info = "You can use the variable 'username' to brute force a single username or the variable ulist to bruteforce a list of usernames. The default 'path' is '/'."
            if username != "":
                self.cmds = [{"name": self.proto + "_brute_hydra_"+self.port, "cmd": "hydra -l "+self.username+" -P "+self.plist+" "+self.host+" "+self.proto+"-get -s "+self.port+" -f -e ns -m "+self.path, "shell": False, "chain": False}]
            else:
                self.cmds = [{"name": self.proto + "_brute_hydra_"+self.port, "cmd": "hydra -L "+self.ulist+" -P "+self.plist+" "+self.host+" "+self.proto+"-get -s "+self.port+" -f -e ns -m "+self.path, "shell": False, "chain": False}]

        dav_auth = "-auth "+self.username+":"+self.password+" " if (self.username and self.password) else ""
        self.demand_cmds=[
            {"name": self.proto + "_slow_dirsearch_"+self.port, "cmd": "dirsearch -f -F -u " + self.proto_host_port + " -e " + self.extensions + " -w /usr/share/wordlists/dirbuster/directory-list-2.3-medium.txt", "shell": False, "chain": False},
            {"name": self.proto + "_sqlmap_"+self.port, "cmd": "sqlmap -u "+self.proto_host_port_path+" --batch --crawl=3 --forms --random-agent --level 1 --risk 1 -f -a" , "shell": False, "chain": False},
            {"name": self.proto + "_davtestmove_"+self.port, "cmd": "davtest "+dav_auth+"-move -sendbd auto -url "+self.proto_host_port_path, "shell": False, "chain": False},
            {"name": self.proto + "_davtestnorm_"+self.port, "cmd": "davtest "+dav_auth+" -sendbd auto -url " + self.proto_host_port_path, "shell": False, "chain": False},
            {"name": self.proto + "_wpscan_"+self.port, "cmd": "wpscan --url "+self.proto_host_port_path+" --rua --no-update --enumerate ap", "shell": False, "chain": False},
            {"name": self.proto + "_cewl_"+self.port, "cmd": "cewl "+self.proto_host_port_path+" -m 6", "shell": False, "chain": False},
            {"name": self.proto + "_arjun_"+self.port, "cmd": "cd "+ self.git_path+"/arjun 2>/dev/null; ./arjun.py --get -u "+self.proto_host_port_path+"; "+
                                                            "./arjun.py --post -u "+self.proto_host_port_path+"; "+
                                                            "./arjun.py --json -u "+self.proto_host_port_path+"; cd - 2>/dev/null",
            "shell": True, "chain": False},
        ]



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior

#You can test this module against sizzle.htb (10.10.10.103)

class Dns_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        # TODO: ADD DNSsec attacks and other IPv6 attacks

        self.cmds = [
            {"name": "dnsrecon_127.0.0.0_24", "cmd": 'dnsrecon -r 127.0.0.0/24 -n ' + self.host, "shell": False, "chain": False},
            {"name": "dnsrecon_127.0.1.0_24", "cmd": 'dnsrecon -r 127.0.1.0/24 -n ' + self.host, "shell": False, "chain": False},
            {"name": "dns_nmap_tcp_"+self.port, "cmd": 'nmap -n -sV --script "(*dns* and (default or (discovery and safe))) or dns-random-txid or dns-random-srcport" -p ' + self.port + ' ' + self.host, "shell": True, "chain": False} ,
            {"name": "dns_nmap_udp_" + self.port,"cmd": 'nmap -n -sV -sU --script "(*dns* and (default or (discovery and safe))) or dns-random-txid or dns-random-srcport" -p ' + self.port + ' ' + self.host,"shell": True, "chain": False},

        ]

        if self.ip != "":
            self.cmds.append({"name": "dig_NS_"+self.port, "cmd": 'dig -x ' + self.ip + ' @' + self.host, "shell": False, "chain": False})
            self.cmds.append({"name": "dnsrecon_"+self.ip+"_24", "cmd": 'dnsrecon -r '+self.ip+'/24 -n ' + self.host, "shell": False, "chain": False})

        if self.ipv6 != "":
            self.cmds.append({"name": "dig_NS", "cmd": 'dig -x ' + self.ipv6 + ' @' + self.host, "shell": False, "chain": False})

        if self.intensity >= "2":
            msfmodules_vuln = [{"path": "auxiliary/scanner/dns/dns_amp", "toset": {"RPORT": self.port, "RHOSTS": self.host}}]
            self.cmds.append({"name": "dns_msf_vuln_"+self.port, "cmd": self.create_msf_cmd(msfmodules_vuln), "shell": True, "chain": False})

        if self.domain != "":
            self.cmds.append({"name": "dig", "cmd": self.dig_cmds(["axfr", "ANY", "A", "AAAA", "TXT", "MX", "NS", "SOA"]), "shell": True, "chain": False})
            self.cmds.append({"name": "dnsrecon_domain", "cmd": 'dnsrecon -d '+ self.domain + ' -a -n '+self.host, "shell": False, "chain": False})
            msfmodules = [{"path": "auxiliary/gather/enum_dns", "toset": {"DOMAIN": self.domain, "NS": self.host}}]
            self.cmds.append({"name": "DNS_msf", "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})

            if self.intensity == "3":
                self.wordlist = self.plist if self.plist != "" else self.wordlists_path+'/subdomains.txt'
                self.cmds = [{"name": "dnsrecon_brute", "cmd": 'dnsrecon -D ' + self.wordlist + ' -d ' + self.domain + ' -n ' + self.host, "shell": False, "chain": False}]


    def dig_cmds(self, cmds):
        final_cmd = ""
        for cmd in cmds:
            final_cmd += "dig "+cmd+" @"+self.host+" "+self.domain+";"
        return final_cmd



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior


class Mysql_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": self.proto+"_version_"+self.port, "cmd": 'nc -w 20 -q 1 -vn ' + self.host + ' ' + self.port + ' </dev/null', "shell": True, "chain": False},
            {"name": self.proto+"_nmap_"+self.port, "cmd": 'nmap -n -sV --script mysql-audit,mysql-databases,mysql-dump-hashes,mysql-empty-password,mysql-enum,mysql-info,mysql-query,mysql-users,mysql-variables,mysql-vuln-cve2012-2122 -p ' + self.port + ' ' + self.host, "shell": True, "chain": False},

        ]

        msfmodules = [
            {"path": "auxiliary/scanner/mysql/mysql_version", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
            {"path": "auxiliary/scanner/mysql/mysql_authbypass_hashdump", "toset": {"RHOSTS": self.host, "RPORT": self.port}},
        ]
        self.cmds.append(
            {"name": self.proto+"_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})

        if self.intensity >= "2":
            self.extra_info = "If you set the username and password, more authenticated metasploit modules will be executed."
            if username != "" and password != "":
                msfmodules_auth = [
                    {"path": "auxiliary/admin/mysql/mysql_enum", "toset": {"RHOSTS": self.host, "RPORT": self.port, "USERNAME": self.username, "PASSWORD": self.password}},
                    {"path": "auxiliary/scanner/mysql/mysql_hashdump", "toset": {"RHOSTS": self.host, "RPORT": self.port, "USERNAME": self.username, "PASSWORD": self.password}},
                    {"path": "auxiliary/scanner/mysql/mysql_schemadump", "toset": {"RHOSTS": self.host, "RPORT": self.port, "USERNAME": self.username, "PASSWORD": self.password}},
                     ]
                self.cmds.append({"name": self.proto+"_msf_auth_"+self.port, "cmd": self.create_msf_cmd(msfmodules_auth), "shell": True, "chain": False})

        if self.intensity == "3":
            self.extra_info = "You can use the variable 'username' to brute force a single username or the variable ulist to bruteforce a list of usernames."
            if username != "":
                self.cmds = [{"name": self.proto+"_brute_hydra_"+self.port, "cmd": 'hydra -f -e ns -l '+self.username+' -P '+self.plist+' -s '+self.port+' '+self.host+' mysql', "shell": True, "chain": False}]
            else:
                self.cmds = [{"name": self.proto+"_brute_hydra_"+self.port, "cmd": 'hydra -f -e ns -L ' + self.ulist + ' -P ' + self.plist + ' -s ' + self.port + ' ' + self.host + ' mysql', "shell": True, "chain": False}]



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior

#You can check this module with irked.htb (10.10.10.117)

class Portmapper_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)


        self.cmds = [
            {"name": "rpcinfo", "cmd": 'rpcinfo ' + self.host, "shell": False, "chain": False},
            {"name": "rpc_nfs_nmap_"+self.port, "cmd": 'nmap -n -sV --script "nfs-ls or nfs-showmount or nfs-statfs" -p ' + self.port + ' ' + self.host, "shell": True, "chain": False},
            {"name": self.proto+"_showmount", "cmd": 'showmount -e ' + self.host, "shell": True, "chain": False},
        ]

        msfmodules = [{"path": "auxiliary/scanner/nfs/nfsmount", "toset": {"RHOSTS": self.host, "RPORT": self.port}}]
        self.cmds.append({"name": self.proto + "_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})



# -*- coding: utf-8 -*-

from warriors.warrior import Warrior


class Afp_warrior (Warrior):
    def __init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec):
        Warrior.__init__(self, host, port, workdir, protocol, intensity, username, ulist, password, plist, notuse, extensions, path, reexec, ipv6, domain, interactive, verbose, executed, exec)

        self.cmds = [
            {"name": self.proto+"_nmap_"+self.port, "cmd": 'nmap -n -sV --script "afp-* and not dos and not brute" -p ' + self.port + ' ' + self.host, "shell": True, "chain": False},

        ]

        msfmodules = [{"path": "auxiliary/scanner/afp/afp_server_info", "toset": {"RHOSTS": self.host, "RPORT": self.port}}]

        self.cmds.append({"name": self.proto+"_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules), "shell": True, "chain": False})

        if self.intensity == "3":
            self.extra_info = "You can use the variable 'username' to brute force a single username or the variable ulist to bruteforce a list of usernames."
            if username != "":
                msfmodules_brute = [{"path": "auxiliary/scanner/afp/afp_login", "toset": {"RHOSTS": self.host, "RPORT": self.port, "BLANK_PASSWORDS": "true", "USER_AS_PASS": "true", "PASS_FILE": self.plist, "USERNAME": self.username}}]
            else:
                msfmodules_brute = [{"path": "auxiliary/scanner/afp/afp_login", "toset": {"RHOSTS": self.host, "RPORT": self.port, "BLANK_PASSWORDS": "true", "USER_AS_PASS": "true", "PASS_FILE": self.plist, "USER_FILE": self.ulist}}]
            self.cmds = [{"name": self.proto+"_brute_msf_"+self.port, "cmd": self.create_msf_cmd(msfmodules_brute), "shell": True, "chain": False}]

